#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayCommerceTransportMessageSendResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceTransportMessageSendResponse, self).__init__()
        self._error_code = None
        self._error_message = None
        self._failed_open_ids = None
        self._failed_user_ids = None
        self._success = None

    @property
    def error_code(self):
        return self._error_code

    @error_code.setter
    def error_code(self, value):
        self._error_code = value
    @property
    def error_message(self):
        return self._error_message

    @error_message.setter
    def error_message(self, value):
        self._error_message = value
    @property
    def failed_open_ids(self):
        return self._failed_open_ids

    @failed_open_ids.setter
    def failed_open_ids(self, value):
        self._failed_open_ids = value
    @property
    def failed_user_ids(self):
        return self._failed_user_ids

    @failed_user_ids.setter
    def failed_user_ids(self, value):
        self._failed_user_ids = value
    @property
    def success(self):
        return self._success

    @success.setter
    def success(self, value):
        self._success = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceTransportMessageSendResponse, self).parse_response_content(response_content)
        if 'error_code' in response:
            self.error_code = response['error_code']
        if 'error_message' in response:
            self.error_message = response['error_message']
        if 'failed_open_ids' in response:
            self.failed_open_ids = response['failed_open_ids']
        if 'failed_user_ids' in response:
            self.failed_user_ids = response['failed_user_ids']
        if 'success' in response:
            self.success = response['success']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MrchCrmUserTagInfo import MrchCrmUserTagInfo


class MrchCrmUser(object):

    def __init__(self):
        self._encrypt_identity_id = None
        self._encrypt_identity_type = None
        self._tag_list = None

    @property
    def encrypt_identity_id(self):
        return self._encrypt_identity_id

    @encrypt_identity_id.setter
    def encrypt_identity_id(self, value):
        self._encrypt_identity_id = value
    @property
    def encrypt_identity_type(self):
        return self._encrypt_identity_type

    @encrypt_identity_type.setter
    def encrypt_identity_type(self, value):
        self._encrypt_identity_type = value
    @property
    def tag_list(self):
        return self._tag_list

    @tag_list.setter
    def tag_list(self, value):
        if isinstance(value, list):
            self._tag_list = list()
            for i in value:
                if isinstance(i, MrchCrmUserTagInfo):
                    self._tag_list.append(i)
                else:
                    self._tag_list.append(MrchCrmUserTagInfo.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.encrypt_identity_id:
            if hasattr(self.encrypt_identity_id, 'to_alipay_dict'):
                params['encrypt_identity_id'] = self.encrypt_identity_id.to_alipay_dict()
            else:
                params['encrypt_identity_id'] = self.encrypt_identity_id
        if self.encrypt_identity_type:
            if hasattr(self.encrypt_identity_type, 'to_alipay_dict'):
                params['encrypt_identity_type'] = self.encrypt_identity_type.to_alipay_dict()
            else:
                params['encrypt_identity_type'] = self.encrypt_identity_type
        if self.tag_list:
            if isinstance(self.tag_list, list):
                for i in range(0, len(self.tag_list)):
                    element = self.tag_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.tag_list[i] = element.to_alipay_dict()
            if hasattr(self.tag_list, 'to_alipay_dict'):
                params['tag_list'] = self.tag_list.to_alipay_dict()
            else:
                params['tag_list'] = self.tag_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MrchCrmUser()
        if 'encrypt_identity_id' in d:
            o.encrypt_identity_id = d['encrypt_identity_id']
        if 'encrypt_identity_type' in d:
            o.encrypt_identity_type = d['encrypt_identity_type']
        if 'tag_list' in d:
            o.tag_list = d['tag_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayBossFncInvmodeCreateModel(object):

    def __init__(self):
        self._ar_no = None
        self._inst_id = None
        self._invoice_mode = None
        self._ip_role_id = None

    @property
    def ar_no(self):
        return self._ar_no

    @ar_no.setter
    def ar_no(self, value):
        self._ar_no = value
    @property
    def inst_id(self):
        return self._inst_id

    @inst_id.setter
    def inst_id(self, value):
        self._inst_id = value
    @property
    def invoice_mode(self):
        return self._invoice_mode

    @invoice_mode.setter
    def invoice_mode(self, value):
        self._invoice_mode = value
    @property
    def ip_role_id(self):
        return self._ip_role_id

    @ip_role_id.setter
    def ip_role_id(self, value):
        self._ip_role_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.ar_no:
            if hasattr(self.ar_no, 'to_alipay_dict'):
                params['ar_no'] = self.ar_no.to_alipay_dict()
            else:
                params['ar_no'] = self.ar_no
        if self.inst_id:
            if hasattr(self.inst_id, 'to_alipay_dict'):
                params['inst_id'] = self.inst_id.to_alipay_dict()
            else:
                params['inst_id'] = self.inst_id
        if self.invoice_mode:
            if hasattr(self.invoice_mode, 'to_alipay_dict'):
                params['invoice_mode'] = self.invoice_mode.to_alipay_dict()
            else:
                params['invoice_mode'] = self.invoice_mode
        if self.ip_role_id:
            if hasattr(self.ip_role_id, 'to_alipay_dict'):
                params['ip_role_id'] = self.ip_role_id.to_alipay_dict()
            else:
                params['ip_role_id'] = self.ip_role_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossFncInvmodeCreateModel()
        if 'ar_no' in d:
            o.ar_no = d['ar_no']
        if 'inst_id' in d:
            o.inst_id = d['inst_id']
        if 'invoice_mode' in d:
            o.invoice_mode = d['invoice_mode']
        if 'ip_role_id' in d:
            o.ip_role_id = d['ip_role_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.RiskStrategy import RiskStrategy


class ZhimaCreditEpRiskInfoIdentifyResponse(AlipayResponse):

    def __init__(self):
        super(ZhimaCreditEpRiskInfoIdentifyResponse, self).__init__()
        self._risk_strategy_list = None

    @property
    def risk_strategy_list(self):
        return self._risk_strategy_list

    @risk_strategy_list.setter
    def risk_strategy_list(self, value):
        if isinstance(value, list):
            self._risk_strategy_list = list()
            for i in value:
                if isinstance(i, RiskStrategy):
                    self._risk_strategy_list.append(i)
                else:
                    self._risk_strategy_list.append(RiskStrategy.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(ZhimaCreditEpRiskInfoIdentifyResponse, self).parse_response_content(response_content)
        if 'risk_strategy_list' in response:
            self.risk_strategy_list = response['risk_strategy_list']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayMarketingActivityOrdervoucherSendResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMarketingActivityOrdervoucherSendResponse, self).__init__()
        self._voucher_code = None

    @property
    def voucher_code(self):
        return self._voucher_code

    @voucher_code.setter
    def voucher_code(self, value):
        self._voucher_code = value

    def parse_response_content(self, response_content):
        response = super(AlipayMarketingActivityOrdervoucherSendResponse, self).parse_response_content(response_content)
        if 'voucher_code' in response:
            self.voucher_code = response['voucher_code']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.MerchantQueryResult import MerchantQueryResult


class AntMerchantExpandInfoQueryResponse(AlipayResponse):

    def __init__(self):
        super(AntMerchantExpandInfoQueryResponse, self).__init__()
        self._merchant_query_result = None

    @property
    def merchant_query_result(self):
        return self._merchant_query_result

    @merchant_query_result.setter
    def merchant_query_result(self, value):
        if isinstance(value, MerchantQueryResult):
            self._merchant_query_result = value
        else:
            self._merchant_query_result = MerchantQueryResult.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AntMerchantExpandInfoQueryResponse, self).parse_response_content(response_content)
        if 'merchant_query_result' in response:
            self.merchant_query_result = response['merchant_query_result']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayPayCodecAcodeDecodeUseResponse(AlipayResponse):

    def __init__(self):
        super(AlipayPayCodecAcodeDecodeUseResponse, self).__init__()
        self._biz_id = None
        self._biz_inst_code = None
        self._business_info = None
        self._create_time = None
        self._encode_inst_code = None
        self._expire_time = None
        self._pay_account = None
        self._pay_account_auth_expire = None
        self._pay_amount_limit = None

    @property
    def biz_id(self):
        return self._biz_id

    @biz_id.setter
    def biz_id(self, value):
        self._biz_id = value
    @property
    def biz_inst_code(self):
        return self._biz_inst_code

    @biz_inst_code.setter
    def biz_inst_code(self, value):
        self._biz_inst_code = value
    @property
    def business_info(self):
        return self._business_info

    @business_info.setter
    def business_info(self, value):
        self._business_info = value
    @property
    def create_time(self):
        return self._create_time

    @create_time.setter
    def create_time(self, value):
        self._create_time = value
    @property
    def encode_inst_code(self):
        return self._encode_inst_code

    @encode_inst_code.setter
    def encode_inst_code(self, value):
        self._encode_inst_code = value
    @property
    def expire_time(self):
        return self._expire_time

    @expire_time.setter
    def expire_time(self, value):
        self._expire_time = value
    @property
    def pay_account(self):
        return self._pay_account

    @pay_account.setter
    def pay_account(self, value):
        self._pay_account = value
    @property
    def pay_account_auth_expire(self):
        return self._pay_account_auth_expire

    @pay_account_auth_expire.setter
    def pay_account_auth_expire(self, value):
        self._pay_account_auth_expire = value
    @property
    def pay_amount_limit(self):
        return self._pay_amount_limit

    @pay_amount_limit.setter
    def pay_amount_limit(self, value):
        self._pay_amount_limit = value

    def parse_response_content(self, response_content):
        response = super(AlipayPayCodecAcodeDecodeUseResponse, self).parse_response_content(response_content)
        if 'biz_id' in response:
            self.biz_id = response['biz_id']
        if 'biz_inst_code' in response:
            self.biz_inst_code = response['biz_inst_code']
        if 'business_info' in response:
            self.business_info = response['business_info']
        if 'create_time' in response:
            self.create_time = response['create_time']
        if 'encode_inst_code' in response:
            self.encode_inst_code = response['encode_inst_code']
        if 'expire_time' in response:
            self.expire_time = response['expire_time']
        if 'pay_account' in response:
            self.pay_account = response['pay_account']
        if 'pay_account_auth_expire' in response:
            self.pay_account_auth_expire = response['pay_account_auth_expire']
        if 'pay_amount_limit' in response:
            self.pay_amount_limit = response['pay_amount_limit']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayPcreditHuabeiPcreditmerchantProductorderDelayResponse(AlipayResponse):

    def __init__(self):
        super(AlipayPcreditHuabeiPcreditmerchantProductorderDelayResponse, self).__init__()
        self._biz_success = None
        self._data = None
        self._error_code = None
        self._error_message = None

    @property
    def biz_success(self):
        return self._biz_success

    @biz_success.setter
    def biz_success(self, value):
        self._biz_success = value
    @property
    def data(self):
        return self._data

    @data.setter
    def data(self, value):
        self._data = value
    @property
    def error_code(self):
        return self._error_code

    @error_code.setter
    def error_code(self, value):
        self._error_code = value
    @property
    def error_message(self):
        return self._error_message

    @error_message.setter
    def error_message(self, value):
        self._error_message = value

    def parse_response_content(self, response_content):
        response = super(AlipayPcreditHuabeiPcreditmerchantProductorderDelayResponse, self).parse_response_content(response_content)
        if 'biz_success' in response:
            self.biz_success = response['biz_success']
        if 'data' in response:
            self.data = response['data']
        if 'error_code' in response:
            self.error_code = response['error_code']
        if 'error_message' in response:
            self.error_message = response['error_message']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFundWalletCardQueryModel(object):

    def __init__(self):
        self._biz_scene = None
        self._biz_type = None
        self._card_no = None
        self._current_page = None
        self._page_size = None
        self._principal_id = None
        self._principal_type = None
        self._product_code = None

    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def card_no(self):
        return self._card_no

    @card_no.setter
    def card_no(self, value):
        self._card_no = value
    @property
    def current_page(self):
        return self._current_page

    @current_page.setter
    def current_page(self, value):
        self._current_page = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def principal_id(self):
        return self._principal_id

    @principal_id.setter
    def principal_id(self, value):
        self._principal_id = value
    @property
    def principal_type(self):
        return self._principal_type

    @principal_type.setter
    def principal_type(self, value):
        self._principal_type = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_scene:
            if hasattr(self.biz_scene, 'to_alipay_dict'):
                params['biz_scene'] = self.biz_scene.to_alipay_dict()
            else:
                params['biz_scene'] = self.biz_scene
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.card_no:
            if hasattr(self.card_no, 'to_alipay_dict'):
                params['card_no'] = self.card_no.to_alipay_dict()
            else:
                params['card_no'] = self.card_no
        if self.current_page:
            if hasattr(self.current_page, 'to_alipay_dict'):
                params['current_page'] = self.current_page.to_alipay_dict()
            else:
                params['current_page'] = self.current_page
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.principal_id:
            if hasattr(self.principal_id, 'to_alipay_dict'):
                params['principal_id'] = self.principal_id.to_alipay_dict()
            else:
                params['principal_id'] = self.principal_id
        if self.principal_type:
            if hasattr(self.principal_type, 'to_alipay_dict'):
                params['principal_type'] = self.principal_type.to_alipay_dict()
            else:
                params['principal_type'] = self.principal_type
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundWalletCardQueryModel()
        if 'biz_scene' in d:
            o.biz_scene = d['biz_scene']
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'card_no' in d:
            o.card_no = d['card_no']
        if 'current_page' in d:
            o.current_page = d['current_page']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'principal_id' in d:
            o.principal_id = d['principal_id']
        if 'principal_type' in d:
            o.principal_type = d['principal_type']
        if 'product_code' in d:
            o.product_code = d['product_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AesElecSignFileDO(object):

    def __init__(self):
        self._file_id = None
        self._file_key = None
        self._file_name = None
        self._file_type = None
        self._gmt_create = None
        self._gmt_modified = None
        self._id = None
        self._related_process_id = None
        self._sign_task_id = None

    @property
    def file_id(self):
        return self._file_id

    @file_id.setter
    def file_id(self, value):
        self._file_id = value
    @property
    def file_key(self):
        return self._file_key

    @file_key.setter
    def file_key(self, value):
        self._file_key = value
    @property
    def file_name(self):
        return self._file_name

    @file_name.setter
    def file_name(self, value):
        self._file_name = value
    @property
    def file_type(self):
        return self._file_type

    @file_type.setter
    def file_type(self, value):
        self._file_type = value
    @property
    def gmt_create(self):
        return self._gmt_create

    @gmt_create.setter
    def gmt_create(self, value):
        self._gmt_create = value
    @property
    def gmt_modified(self):
        return self._gmt_modified

    @gmt_modified.setter
    def gmt_modified(self, value):
        self._gmt_modified = value
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def related_process_id(self):
        return self._related_process_id

    @related_process_id.setter
    def related_process_id(self, value):
        self._related_process_id = value
    @property
    def sign_task_id(self):
        return self._sign_task_id

    @sign_task_id.setter
    def sign_task_id(self, value):
        self._sign_task_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.file_id:
            if hasattr(self.file_id, 'to_alipay_dict'):
                params['file_id'] = self.file_id.to_alipay_dict()
            else:
                params['file_id'] = self.file_id
        if self.file_key:
            if hasattr(self.file_key, 'to_alipay_dict'):
                params['file_key'] = self.file_key.to_alipay_dict()
            else:
                params['file_key'] = self.file_key
        if self.file_name:
            if hasattr(self.file_name, 'to_alipay_dict'):
                params['file_name'] = self.file_name.to_alipay_dict()
            else:
                params['file_name'] = self.file_name
        if self.file_type:
            if hasattr(self.file_type, 'to_alipay_dict'):
                params['file_type'] = self.file_type.to_alipay_dict()
            else:
                params['file_type'] = self.file_type
        if self.gmt_create:
            if hasattr(self.gmt_create, 'to_alipay_dict'):
                params['gmt_create'] = self.gmt_create.to_alipay_dict()
            else:
                params['gmt_create'] = self.gmt_create
        if self.gmt_modified:
            if hasattr(self.gmt_modified, 'to_alipay_dict'):
                params['gmt_modified'] = self.gmt_modified.to_alipay_dict()
            else:
                params['gmt_modified'] = self.gmt_modified
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.related_process_id:
            if hasattr(self.related_process_id, 'to_alipay_dict'):
                params['related_process_id'] = self.related_process_id.to_alipay_dict()
            else:
                params['related_process_id'] = self.related_process_id
        if self.sign_task_id:
            if hasattr(self.sign_task_id, 'to_alipay_dict'):
                params['sign_task_id'] = self.sign_task_id.to_alipay_dict()
            else:
                params['sign_task_id'] = self.sign_task_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AesElecSignFileDO()
        if 'file_id' in d:
            o.file_id = d['file_id']
        if 'file_key' in d:
            o.file_key = d['file_key']
        if 'file_name' in d:
            o.file_name = d['file_name']
        if 'file_type' in d:
            o.file_type = d['file_type']
        if 'gmt_create' in d:
            o.gmt_create = d['gmt_create']
        if 'gmt_modified' in d:
            o.gmt_modified = d['gmt_modified']
        if 'id' in d:
            o.id = d['id']
        if 'related_process_id' in d:
            o.related_process_id = d['related_process_id']
        if 'sign_task_id' in d:
            o.sign_task_id = d['sign_task_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenMiniExperienceCreateModel(object):

    def __init__(self):
        self._app_version = None
        self._bundle_id = None

    @property
    def app_version(self):
        return self._app_version

    @app_version.setter
    def app_version(self, value):
        self._app_version = value
    @property
    def bundle_id(self):
        return self._bundle_id

    @bundle_id.setter
    def bundle_id(self, value):
        self._bundle_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_version:
            if hasattr(self.app_version, 'to_alipay_dict'):
                params['app_version'] = self.app_version.to_alipay_dict()
            else:
                params['app_version'] = self.app_version
        if self.bundle_id:
            if hasattr(self.bundle_id, 'to_alipay_dict'):
                params['bundle_id'] = self.bundle_id.to_alipay_dict()
            else:
                params['bundle_id'] = self.bundle_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniExperienceCreateModel()
        if 'app_version' in d:
            o.app_version = d['app_version']
        if 'bundle_id' in d:
            o.bundle_id = d['bundle_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenAuthUnifygwtestQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenAuthUnifygwtestQueryResponse, self).__init__()
        self._des = None

    @property
    def des(self):
        return self._des

    @des.setter
    def des(self, value):
        self._des = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenAuthUnifygwtestQueryResponse, self).parse_response_content(response_content)
        if 'des' in response:
            self.des = response['des']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.TradeItemResult import TradeItemResult


class AlipayDataBillBuyQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayDataBillBuyQueryResponse, self).__init__()
        self._detail_list = None
        self._page_no = None
        self._page_size = None
        self._total_size = None

    @property
    def detail_list(self):
        return self._detail_list

    @detail_list.setter
    def detail_list(self, value):
        if isinstance(value, list):
            self._detail_list = list()
            for i in value:
                if isinstance(i, TradeItemResult):
                    self._detail_list.append(i)
                else:
                    self._detail_list.append(TradeItemResult.from_alipay_dict(i))
    @property
    def page_no(self):
        return self._page_no

    @page_no.setter
    def page_no(self, value):
        self._page_no = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def total_size(self):
        return self._total_size

    @total_size.setter
    def total_size(self, value):
        self._total_size = value

    def parse_response_content(self, response_content):
        response = super(AlipayDataBillBuyQueryResponse, self).parse_response_content(response_content)
        if 'detail_list' in response:
            self.detail_list = response['detail_list']
        if 'page_no' in response:
            self.page_no = response['page_no']
        if 'page_size' in response:
            self.page_size = response['page_size']
        if 'total_size' in response:
            self.total_size = response['total_size']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayDataIotdataSearchlibraryBaiQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayDataIotdataSearchlibraryBaiQueryResponse, self).__init__()
        self._model_info = None
        self._repeat_info = None
        self._similarity_info = None

    @property
    def model_info(self):
        return self._model_info

    @model_info.setter
    def model_info(self, value):
        self._model_info = value
    @property
    def repeat_info(self):
        return self._repeat_info

    @repeat_info.setter
    def repeat_info(self, value):
        self._repeat_info = value
    @property
    def similarity_info(self):
        return self._similarity_info

    @similarity_info.setter
    def similarity_info(self, value):
        self._similarity_info = value

    def parse_response_content(self, response_content):
        response = super(AlipayDataIotdataSearchlibraryBaiQueryResponse, self).parse_response_content(response_content)
        if 'model_info' in response:
            self.model_info = response['model_info']
        if 'repeat_info' in response:
            self.repeat_info = response['repeat_info']
        if 'similarity_info' in response:
            self.similarity_info = response['similarity_info']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFundTransPayeeBindQueryModel(object):

    def __init__(self):
        self._identity = None
        self._identity_type = None

    @property
    def identity(self):
        return self._identity

    @identity.setter
    def identity(self, value):
        self._identity = value
    @property
    def identity_type(self):
        return self._identity_type

    @identity_type.setter
    def identity_type(self, value):
        self._identity_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.identity:
            if hasattr(self.identity, 'to_alipay_dict'):
                params['identity'] = self.identity.to_alipay_dict()
            else:
                params['identity'] = self.identity
        if self.identity_type:
            if hasattr(self.identity_type, 'to_alipay_dict'):
                params['identity_type'] = self.identity_type.to_alipay_dict()
            else:
                params['identity_type'] = self.identity_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundTransPayeeBindQueryModel()
        if 'identity' in d:
            o.identity = d['identity']
        if 'identity_type' in d:
            o.identity_type = d['identity_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class NimitzCell(object):

    def __init__(self):
        self._b_val = None
        self._d_val = None
        self._i_64_val = None
        self._s_val = None

    @property
    def b_val(self):
        return self._b_val

    @b_val.setter
    def b_val(self, value):
        self._b_val = value
    @property
    def d_val(self):
        return self._d_val

    @d_val.setter
    def d_val(self, value):
        self._d_val = value
    @property
    def i_64_val(self):
        return self._i_64_val

    @i_64_val.setter
    def i_64_val(self, value):
        self._i_64_val = value
    @property
    def s_val(self):
        return self._s_val

    @s_val.setter
    def s_val(self, value):
        self._s_val = value


    def to_alipay_dict(self):
        params = dict()
        if self.b_val:
            if hasattr(self.b_val, 'to_alipay_dict'):
                params['b_val'] = self.b_val.to_alipay_dict()
            else:
                params['b_val'] = self.b_val
        if self.d_val:
            if hasattr(self.d_val, 'to_alipay_dict'):
                params['d_val'] = self.d_val.to_alipay_dict()
            else:
                params['d_val'] = self.d_val
        if self.i_64_val:
            if hasattr(self.i_64_val, 'to_alipay_dict'):
                params['i_64_val'] = self.i_64_val.to_alipay_dict()
            else:
                params['i_64_val'] = self.i_64_val
        if self.s_val:
            if hasattr(self.s_val, 'to_alipay_dict'):
                params['s_val'] = self.s_val.to_alipay_dict()
            else:
                params['s_val'] = self.s_val
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = NimitzCell()
        if 'b_val' in d:
            o.b_val = d['b_val']
        if 'd_val' in d:
            o.d_val = d['d_val']
        if 'i_64_val' in d:
            o.i_64_val = d['i_64_val']
        if 's_val' in d:
            o.s_val = d['s_val']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayTradeOrderPrepayResponse(AlipayResponse):

    def __init__(self):
        super(AlipayTradeOrderPrepayResponse, self).__init__()
        self._out_trade_no = None
        self._tn = None
        self._trade_no = None

    @property
    def out_trade_no(self):
        return self._out_trade_no

    @out_trade_no.setter
    def out_trade_no(self, value):
        self._out_trade_no = value
    @property
    def tn(self):
        return self._tn

    @tn.setter
    def tn(self, value):
        self._tn = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value

    def parse_response_content(self, response_content):
        response = super(AlipayTradeOrderPrepayResponse, self).parse_response_content(response_content)
        if 'out_trade_no' in response:
            self.out_trade_no = response['out_trade_no']
        if 'tn' in response:
            self.tn = response['tn']
        if 'trade_no' in response:
            self.trade_no = response['trade_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayDataDataserviceAdPrincipaldmpSetModel(object):

    def __init__(self):
        self._biz_token = None
        self._data_id = None
        self._status = None

    @property
    def biz_token(self):
        return self._biz_token

    @biz_token.setter
    def biz_token(self, value):
        self._biz_token = value
    @property
    def data_id(self):
        return self._data_id

    @data_id.setter
    def data_id(self, value):
        self._data_id = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_token:
            if hasattr(self.biz_token, 'to_alipay_dict'):
                params['biz_token'] = self.biz_token.to_alipay_dict()
            else:
                params['biz_token'] = self.biz_token
        if self.data_id:
            if hasattr(self.data_id, 'to_alipay_dict'):
                params['data_id'] = self.data_id.to_alipay_dict()
            else:
                params['data_id'] = self.data_id
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayDataDataserviceAdPrincipaldmpSetModel()
        if 'biz_token' in d:
            o.biz_token = d['biz_token']
        if 'data_id' in d:
            o.data_id = d['data_id']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class FengdieSpaceDomains(object):

    def __init__(self):
        self._domain = None
        self._is_default = None
        self._status = None

    @property
    def domain(self):
        return self._domain

    @domain.setter
    def domain(self, value):
        self._domain = value
    @property
    def is_default(self):
        return self._is_default

    @is_default.setter
    def is_default(self, value):
        self._is_default = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.domain:
            if hasattr(self.domain, 'to_alipay_dict'):
                params['domain'] = self.domain.to_alipay_dict()
            else:
                params['domain'] = self.domain
        if self.is_default:
            if hasattr(self.is_default, 'to_alipay_dict'):
                params['is_default'] = self.is_default.to_alipay_dict()
            else:
                params['is_default'] = self.is_default
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = FengdieSpaceDomains()
        if 'domain' in d:
            o.domain = d['domain']
        if 'is_default' in d:
            o.is_default = d['is_default']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class InsCoverage(object):

    def __init__(self):
        self._coverage_name = None
        self._coverage_no = None
        self._effect_end_time = None
        self._effect_start_time = None
        self._iop = None
        self._iop_premium = None
        self._premium = None
        self._sum_insured = None

    @property
    def coverage_name(self):
        return self._coverage_name

    @coverage_name.setter
    def coverage_name(self, value):
        self._coverage_name = value
    @property
    def coverage_no(self):
        return self._coverage_no

    @coverage_no.setter
    def coverage_no(self, value):
        self._coverage_no = value
    @property
    def effect_end_time(self):
        return self._effect_end_time

    @effect_end_time.setter
    def effect_end_time(self, value):
        self._effect_end_time = value
    @property
    def effect_start_time(self):
        return self._effect_start_time

    @effect_start_time.setter
    def effect_start_time(self, value):
        self._effect_start_time = value
    @property
    def iop(self):
        return self._iop

    @iop.setter
    def iop(self, value):
        self._iop = value
    @property
    def iop_premium(self):
        return self._iop_premium

    @iop_premium.setter
    def iop_premium(self, value):
        self._iop_premium = value
    @property
    def premium(self):
        return self._premium

    @premium.setter
    def premium(self, value):
        self._premium = value
    @property
    def sum_insured(self):
        return self._sum_insured

    @sum_insured.setter
    def sum_insured(self, value):
        self._sum_insured = value


    def to_alipay_dict(self):
        params = dict()
        if self.coverage_name:
            if hasattr(self.coverage_name, 'to_alipay_dict'):
                params['coverage_name'] = self.coverage_name.to_alipay_dict()
            else:
                params['coverage_name'] = self.coverage_name
        if self.coverage_no:
            if hasattr(self.coverage_no, 'to_alipay_dict'):
                params['coverage_no'] = self.coverage_no.to_alipay_dict()
            else:
                params['coverage_no'] = self.coverage_no
        if self.effect_end_time:
            if hasattr(self.effect_end_time, 'to_alipay_dict'):
                params['effect_end_time'] = self.effect_end_time.to_alipay_dict()
            else:
                params['effect_end_time'] = self.effect_end_time
        if self.effect_start_time:
            if hasattr(self.effect_start_time, 'to_alipay_dict'):
                params['effect_start_time'] = self.effect_start_time.to_alipay_dict()
            else:
                params['effect_start_time'] = self.effect_start_time
        if self.iop:
            if hasattr(self.iop, 'to_alipay_dict'):
                params['iop'] = self.iop.to_alipay_dict()
            else:
                params['iop'] = self.iop
        if self.iop_premium:
            if hasattr(self.iop_premium, 'to_alipay_dict'):
                params['iop_premium'] = self.iop_premium.to_alipay_dict()
            else:
                params['iop_premium'] = self.iop_premium
        if self.premium:
            if hasattr(self.premium, 'to_alipay_dict'):
                params['premium'] = self.premium.to_alipay_dict()
            else:
                params['premium'] = self.premium
        if self.sum_insured:
            if hasattr(self.sum_insured, 'to_alipay_dict'):
                params['sum_insured'] = self.sum_insured.to_alipay_dict()
            else:
                params['sum_insured'] = self.sum_insured
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InsCoverage()
        if 'coverage_name' in d:
            o.coverage_name = d['coverage_name']
        if 'coverage_no' in d:
            o.coverage_no = d['coverage_no']
        if 'effect_end_time' in d:
            o.effect_end_time = d['effect_end_time']
        if 'effect_start_time' in d:
            o.effect_start_time = d['effect_start_time']
        if 'iop' in d:
            o.iop = d['iop']
        if 'iop_premium' in d:
            o.iop_premium = d['iop_premium']
        if 'premium' in d:
            o.premium = d['premium']
        if 'sum_insured' in d:
            o.sum_insured = d['sum_insured']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.SettleCardInfo import SettleCardInfo
from alipay.aop.api.domain.AddressInfo import AddressInfo
from alipay.aop.api.domain.ContactInfo import ContactInfo
from alipay.aop.api.domain.DefaultSettleRule import DefaultSettleRule
from alipay.aop.api.domain.MerchantInvoiceInfo import MerchantInvoiceInfo
from alipay.aop.api.domain.IndustryQualificationInfo import IndustryQualificationInfo
from alipay.aop.api.domain.SiteInfo import SiteInfo


class AntMerchantExpandIndirectZftModifyModel(object):

    def __init__(self):
        self._additional_cert_image = None
        self._additional_cert_no = None
        self._additional_cert_type = None
        self._alias_name = None
        self._alipay_logon_id = None
        self._binding_alipay_logon_id = None
        self._biz_cards = None
        self._business_address = None
        self._cert_image = None
        self._cert_image_back = None
        self._cert_type = None
        self._contact_infos = None
        self._default_settle_rule = None
        self._external_id = None
        self._in_door_images = None
        self._info_source_open_id = None
        self._info_source_uid = None
        self._invoice_info = None
        self._legal_cert_back_image = None
        self._legal_cert_front_image = None
        self._legal_cert_no = None
        self._legal_cert_type = None
        self._legal_name = None
        self._license_auth_letter_image = None
        self._mcc = None
        self._merchant_type = None
        self._name = None
        self._out_door_images = None
        self._oversea_settle_account = None
        self._oversea_settle_open_id = None
        self._qualifications = None
        self._service = None
        self._service_phone = None
        self._sign_time_with_isv = None
        self._sites = None
        self._smid = None

    @property
    def additional_cert_image(self):
        return self._additional_cert_image

    @additional_cert_image.setter
    def additional_cert_image(self, value):
        self._additional_cert_image = value
    @property
    def additional_cert_no(self):
        return self._additional_cert_no

    @additional_cert_no.setter
    def additional_cert_no(self, value):
        self._additional_cert_no = value
    @property
    def additional_cert_type(self):
        return self._additional_cert_type

    @additional_cert_type.setter
    def additional_cert_type(self, value):
        self._additional_cert_type = value
    @property
    def alias_name(self):
        return self._alias_name

    @alias_name.setter
    def alias_name(self, value):
        self._alias_name = value
    @property
    def alipay_logon_id(self):
        return self._alipay_logon_id

    @alipay_logon_id.setter
    def alipay_logon_id(self, value):
        self._alipay_logon_id = value
    @property
    def binding_alipay_logon_id(self):
        return self._binding_alipay_logon_id

    @binding_alipay_logon_id.setter
    def binding_alipay_logon_id(self, value):
        self._binding_alipay_logon_id = value
    @property
    def biz_cards(self):
        return self._biz_cards

    @biz_cards.setter
    def biz_cards(self, value):
        if isinstance(value, list):
            self._biz_cards = list()
            for i in value:
                if isinstance(i, SettleCardInfo):
                    self._biz_cards.append(i)
                else:
                    self._biz_cards.append(SettleCardInfo.from_alipay_dict(i))
    @property
    def business_address(self):
        return self._business_address

    @business_address.setter
    def business_address(self, value):
        if isinstance(value, AddressInfo):
            self._business_address = value
        else:
            self._business_address = AddressInfo.from_alipay_dict(value)
    @property
    def cert_image(self):
        return self._cert_image

    @cert_image.setter
    def cert_image(self, value):
        self._cert_image = value
    @property
    def cert_image_back(self):
        return self._cert_image_back

    @cert_image_back.setter
    def cert_image_back(self, value):
        self._cert_image_back = value
    @property
    def cert_type(self):
        return self._cert_type

    @cert_type.setter
    def cert_type(self, value):
        self._cert_type = value
    @property
    def contact_infos(self):
        return self._contact_infos

    @contact_infos.setter
    def contact_infos(self, value):
        if isinstance(value, list):
            self._contact_infos = list()
            for i in value:
                if isinstance(i, ContactInfo):
                    self._contact_infos.append(i)
                else:
                    self._contact_infos.append(ContactInfo.from_alipay_dict(i))
    @property
    def default_settle_rule(self):
        return self._default_settle_rule

    @default_settle_rule.setter
    def default_settle_rule(self, value):
        if isinstance(value, DefaultSettleRule):
            self._default_settle_rule = value
        else:
            self._default_settle_rule = DefaultSettleRule.from_alipay_dict(value)
    @property
    def external_id(self):
        return self._external_id

    @external_id.setter
    def external_id(self, value):
        self._external_id = value
    @property
    def in_door_images(self):
        return self._in_door_images

    @in_door_images.setter
    def in_door_images(self, value):
        if isinstance(value, list):
            self._in_door_images = list()
            for i in value:
                self._in_door_images.append(i)
    @property
    def info_source_open_id(self):
        return self._info_source_open_id

    @info_source_open_id.setter
    def info_source_open_id(self, value):
        self._info_source_open_id = value
    @property
    def info_source_uid(self):
        return self._info_source_uid

    @info_source_uid.setter
    def info_source_uid(self, value):
        self._info_source_uid = value
    @property
    def invoice_info(self):
        return self._invoice_info

    @invoice_info.setter
    def invoice_info(self, value):
        if isinstance(value, MerchantInvoiceInfo):
            self._invoice_info = value
        else:
            self._invoice_info = MerchantInvoiceInfo.from_alipay_dict(value)
    @property
    def legal_cert_back_image(self):
        return self._legal_cert_back_image

    @legal_cert_back_image.setter
    def legal_cert_back_image(self, value):
        self._legal_cert_back_image = value
    @property
    def legal_cert_front_image(self):
        return self._legal_cert_front_image

    @legal_cert_front_image.setter
    def legal_cert_front_image(self, value):
        self._legal_cert_front_image = value
    @property
    def legal_cert_no(self):
        return self._legal_cert_no

    @legal_cert_no.setter
    def legal_cert_no(self, value):
        self._legal_cert_no = value
    @property
    def legal_cert_type(self):
        return self._legal_cert_type

    @legal_cert_type.setter
    def legal_cert_type(self, value):
        self._legal_cert_type = value
    @property
    def legal_name(self):
        return self._legal_name

    @legal_name.setter
    def legal_name(self, value):
        self._legal_name = value
    @property
    def license_auth_letter_image(self):
        return self._license_auth_letter_image

    @license_auth_letter_image.setter
    def license_auth_letter_image(self, value):
        self._license_auth_letter_image = value
    @property
    def mcc(self):
        return self._mcc

    @mcc.setter
    def mcc(self, value):
        self._mcc = value
    @property
    def merchant_type(self):
        return self._merchant_type

    @merchant_type.setter
    def merchant_type(self, value):
        self._merchant_type = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def out_door_images(self):
        return self._out_door_images

    @out_door_images.setter
    def out_door_images(self, value):
        if isinstance(value, list):
            self._out_door_images = list()
            for i in value:
                self._out_door_images.append(i)
    @property
    def oversea_settle_account(self):
        return self._oversea_settle_account

    @oversea_settle_account.setter
    def oversea_settle_account(self, value):
        self._oversea_settle_account = value
    @property
    def oversea_settle_open_id(self):
        return self._oversea_settle_open_id

    @oversea_settle_open_id.setter
    def oversea_settle_open_id(self, value):
        self._oversea_settle_open_id = value
    @property
    def qualifications(self):
        return self._qualifications

    @qualifications.setter
    def qualifications(self, value):
        if isinstance(value, list):
            self._qualifications = list()
            for i in value:
                if isinstance(i, IndustryQualificationInfo):
                    self._qualifications.append(i)
                else:
                    self._qualifications.append(IndustryQualificationInfo.from_alipay_dict(i))
    @property
    def service(self):
        return self._service

    @service.setter
    def service(self, value):
        if isinstance(value, list):
            self._service = list()
            for i in value:
                self._service.append(i)
    @property
    def service_phone(self):
        return self._service_phone

    @service_phone.setter
    def service_phone(self, value):
        self._service_phone = value
    @property
    def sign_time_with_isv(self):
        return self._sign_time_with_isv

    @sign_time_with_isv.setter
    def sign_time_with_isv(self, value):
        self._sign_time_with_isv = value
    @property
    def sites(self):
        return self._sites

    @sites.setter
    def sites(self, value):
        if isinstance(value, list):
            self._sites = list()
            for i in value:
                if isinstance(i, SiteInfo):
                    self._sites.append(i)
                else:
                    self._sites.append(SiteInfo.from_alipay_dict(i))
    @property
    def smid(self):
        return self._smid

    @smid.setter
    def smid(self, value):
        self._smid = value


    def to_alipay_dict(self):
        params = dict()
        if self.additional_cert_image:
            if hasattr(self.additional_cert_image, 'to_alipay_dict'):
                params['additional_cert_image'] = self.additional_cert_image.to_alipay_dict()
            else:
                params['additional_cert_image'] = self.additional_cert_image
        if self.additional_cert_no:
            if hasattr(self.additional_cert_no, 'to_alipay_dict'):
                params['additional_cert_no'] = self.additional_cert_no.to_alipay_dict()
            else:
                params['additional_cert_no'] = self.additional_cert_no
        if self.additional_cert_type:
            if hasattr(self.additional_cert_type, 'to_alipay_dict'):
                params['additional_cert_type'] = self.additional_cert_type.to_alipay_dict()
            else:
                params['additional_cert_type'] = self.additional_cert_type
        if self.alias_name:
            if hasattr(self.alias_name, 'to_alipay_dict'):
                params['alias_name'] = self.alias_name.to_alipay_dict()
            else:
                params['alias_name'] = self.alias_name
        if self.alipay_logon_id:
            if hasattr(self.alipay_logon_id, 'to_alipay_dict'):
                params['alipay_logon_id'] = self.alipay_logon_id.to_alipay_dict()
            else:
                params['alipay_logon_id'] = self.alipay_logon_id
        if self.binding_alipay_logon_id:
            if hasattr(self.binding_alipay_logon_id, 'to_alipay_dict'):
                params['binding_alipay_logon_id'] = self.binding_alipay_logon_id.to_alipay_dict()
            else:
                params['binding_alipay_logon_id'] = self.binding_alipay_logon_id
        if self.biz_cards:
            if isinstance(self.biz_cards, list):
                for i in range(0, len(self.biz_cards)):
                    element = self.biz_cards[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.biz_cards[i] = element.to_alipay_dict()
            if hasattr(self.biz_cards, 'to_alipay_dict'):
                params['biz_cards'] = self.biz_cards.to_alipay_dict()
            else:
                params['biz_cards'] = self.biz_cards
        if self.business_address:
            if hasattr(self.business_address, 'to_alipay_dict'):
                params['business_address'] = self.business_address.to_alipay_dict()
            else:
                params['business_address'] = self.business_address
        if self.cert_image:
            if hasattr(self.cert_image, 'to_alipay_dict'):
                params['cert_image'] = self.cert_image.to_alipay_dict()
            else:
                params['cert_image'] = self.cert_image
        if self.cert_image_back:
            if hasattr(self.cert_image_back, 'to_alipay_dict'):
                params['cert_image_back'] = self.cert_image_back.to_alipay_dict()
            else:
                params['cert_image_back'] = self.cert_image_back
        if self.cert_type:
            if hasattr(self.cert_type, 'to_alipay_dict'):
                params['cert_type'] = self.cert_type.to_alipay_dict()
            else:
                params['cert_type'] = self.cert_type
        if self.contact_infos:
            if isinstance(self.contact_infos, list):
                for i in range(0, len(self.contact_infos)):
                    element = self.contact_infos[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.contact_infos[i] = element.to_alipay_dict()
            if hasattr(self.contact_infos, 'to_alipay_dict'):
                params['contact_infos'] = self.contact_infos.to_alipay_dict()
            else:
                params['contact_infos'] = self.contact_infos
        if self.default_settle_rule:
            if hasattr(self.default_settle_rule, 'to_alipay_dict'):
                params['default_settle_rule'] = self.default_settle_rule.to_alipay_dict()
            else:
                params['default_settle_rule'] = self.default_settle_rule
        if self.external_id:
            if hasattr(self.external_id, 'to_alipay_dict'):
                params['external_id'] = self.external_id.to_alipay_dict()
            else:
                params['external_id'] = self.external_id
        if self.in_door_images:
            if isinstance(self.in_door_images, list):
                for i in range(0, len(self.in_door_images)):
                    element = self.in_door_images[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.in_door_images[i] = element.to_alipay_dict()
            if hasattr(self.in_door_images, 'to_alipay_dict'):
                params['in_door_images'] = self.in_door_images.to_alipay_dict()
            else:
                params['in_door_images'] = self.in_door_images
        if self.info_source_open_id:
            if hasattr(self.info_source_open_id, 'to_alipay_dict'):
                params['info_source_open_id'] = self.info_source_open_id.to_alipay_dict()
            else:
                params['info_source_open_id'] = self.info_source_open_id
        if self.info_source_uid:
            if hasattr(self.info_source_uid, 'to_alipay_dict'):
                params['info_source_uid'] = self.info_source_uid.to_alipay_dict()
            else:
                params['info_source_uid'] = self.info_source_uid
        if self.invoice_info:
            if hasattr(self.invoice_info, 'to_alipay_dict'):
                params['invoice_info'] = self.invoice_info.to_alipay_dict()
            else:
                params['invoice_info'] = self.invoice_info
        if self.legal_cert_back_image:
            if hasattr(self.legal_cert_back_image, 'to_alipay_dict'):
                params['legal_cert_back_image'] = self.legal_cert_back_image.to_alipay_dict()
            else:
                params['legal_cert_back_image'] = self.legal_cert_back_image
        if self.legal_cert_front_image:
            if hasattr(self.legal_cert_front_image, 'to_alipay_dict'):
                params['legal_cert_front_image'] = self.legal_cert_front_image.to_alipay_dict()
            else:
                params['legal_cert_front_image'] = self.legal_cert_front_image
        if self.legal_cert_no:
            if hasattr(self.legal_cert_no, 'to_alipay_dict'):
                params['legal_cert_no'] = self.legal_cert_no.to_alipay_dict()
            else:
                params['legal_cert_no'] = self.legal_cert_no
        if self.legal_cert_type:
            if hasattr(self.legal_cert_type, 'to_alipay_dict'):
                params['legal_cert_type'] = self.legal_cert_type.to_alipay_dict()
            else:
                params['legal_cert_type'] = self.legal_cert_type
        if self.legal_name:
            if hasattr(self.legal_name, 'to_alipay_dict'):
                params['legal_name'] = self.legal_name.to_alipay_dict()
            else:
                params['legal_name'] = self.legal_name
        if self.license_auth_letter_image:
            if hasattr(self.license_auth_letter_image, 'to_alipay_dict'):
                params['license_auth_letter_image'] = self.license_auth_letter_image.to_alipay_dict()
            else:
                params['license_auth_letter_image'] = self.license_auth_letter_image
        if self.mcc:
            if hasattr(self.mcc, 'to_alipay_dict'):
                params['mcc'] = self.mcc.to_alipay_dict()
            else:
                params['mcc'] = self.mcc
        if self.merchant_type:
            if hasattr(self.merchant_type, 'to_alipay_dict'):
                params['merchant_type'] = self.merchant_type.to_alipay_dict()
            else:
                params['merchant_type'] = self.merchant_type
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.out_door_images:
            if isinstance(self.out_door_images, list):
                for i in range(0, len(self.out_door_images)):
                    element = self.out_door_images[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.out_door_images[i] = element.to_alipay_dict()
            if hasattr(self.out_door_images, 'to_alipay_dict'):
                params['out_door_images'] = self.out_door_images.to_alipay_dict()
            else:
                params['out_door_images'] = self.out_door_images
        if self.oversea_settle_account:
            if hasattr(self.oversea_settle_account, 'to_alipay_dict'):
                params['oversea_settle_account'] = self.oversea_settle_account.to_alipay_dict()
            else:
                params['oversea_settle_account'] = self.oversea_settle_account
        if self.oversea_settle_open_id:
            if hasattr(self.oversea_settle_open_id, 'to_alipay_dict'):
                params['oversea_settle_open_id'] = self.oversea_settle_open_id.to_alipay_dict()
            else:
                params['oversea_settle_open_id'] = self.oversea_settle_open_id
        if self.qualifications:
            if isinstance(self.qualifications, list):
                for i in range(0, len(self.qualifications)):
                    element = self.qualifications[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.qualifications[i] = element.to_alipay_dict()
            if hasattr(self.qualifications, 'to_alipay_dict'):
                params['qualifications'] = self.qualifications.to_alipay_dict()
            else:
                params['qualifications'] = self.qualifications
        if self.service:
            if isinstance(self.service, list):
                for i in range(0, len(self.service)):
                    element = self.service[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.service[i] = element.to_alipay_dict()
            if hasattr(self.service, 'to_alipay_dict'):
                params['service'] = self.service.to_alipay_dict()
            else:
                params['service'] = self.service
        if self.service_phone:
            if hasattr(self.service_phone, 'to_alipay_dict'):
                params['service_phone'] = self.service_phone.to_alipay_dict()
            else:
                params['service_phone'] = self.service_phone
        if self.sign_time_with_isv:
            if hasattr(self.sign_time_with_isv, 'to_alipay_dict'):
                params['sign_time_with_isv'] = self.sign_time_with_isv.to_alipay_dict()
            else:
                params['sign_time_with_isv'] = self.sign_time_with_isv
        if self.sites:
            if isinstance(self.sites, list):
                for i in range(0, len(self.sites)):
                    element = self.sites[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.sites[i] = element.to_alipay_dict()
            if hasattr(self.sites, 'to_alipay_dict'):
                params['sites'] = self.sites.to_alipay_dict()
            else:
                params['sites'] = self.sites
        if self.smid:
            if hasattr(self.smid, 'to_alipay_dict'):
                params['smid'] = self.smid.to_alipay_dict()
            else:
                params['smid'] = self.smid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntMerchantExpandIndirectZftModifyModel()
        if 'additional_cert_image' in d:
            o.additional_cert_image = d['additional_cert_image']
        if 'additional_cert_no' in d:
            o.additional_cert_no = d['additional_cert_no']
        if 'additional_cert_type' in d:
            o.additional_cert_type = d['additional_cert_type']
        if 'alias_name' in d:
            o.alias_name = d['alias_name']
        if 'alipay_logon_id' in d:
            o.alipay_logon_id = d['alipay_logon_id']
        if 'binding_alipay_logon_id' in d:
            o.binding_alipay_logon_id = d['binding_alipay_logon_id']
        if 'biz_cards' in d:
            o.biz_cards = d['biz_cards']
        if 'business_address' in d:
            o.business_address = d['business_address']
        if 'cert_image' in d:
            o.cert_image = d['cert_image']
        if 'cert_image_back' in d:
            o.cert_image_back = d['cert_image_back']
        if 'cert_type' in d:
            o.cert_type = d['cert_type']
        if 'contact_infos' in d:
            o.contact_infos = d['contact_infos']
        if 'default_settle_rule' in d:
            o.default_settle_rule = d['default_settle_rule']
        if 'external_id' in d:
            o.external_id = d['external_id']
        if 'in_door_images' in d:
            o.in_door_images = d['in_door_images']
        if 'info_source_open_id' in d:
            o.info_source_open_id = d['info_source_open_id']
        if 'info_source_uid' in d:
            o.info_source_uid = d['info_source_uid']
        if 'invoice_info' in d:
            o.invoice_info = d['invoice_info']
        if 'legal_cert_back_image' in d:
            o.legal_cert_back_image = d['legal_cert_back_image']
        if 'legal_cert_front_image' in d:
            o.legal_cert_front_image = d['legal_cert_front_image']
        if 'legal_cert_no' in d:
            o.legal_cert_no = d['legal_cert_no']
        if 'legal_cert_type' in d:
            o.legal_cert_type = d['legal_cert_type']
        if 'legal_name' in d:
            o.legal_name = d['legal_name']
        if 'license_auth_letter_image' in d:
            o.license_auth_letter_image = d['license_auth_letter_image']
        if 'mcc' in d:
            o.mcc = d['mcc']
        if 'merchant_type' in d:
            o.merchant_type = d['merchant_type']
        if 'name' in d:
            o.name = d['name']
        if 'out_door_images' in d:
            o.out_door_images = d['out_door_images']
        if 'oversea_settle_account' in d:
            o.oversea_settle_account = d['oversea_settle_account']
        if 'oversea_settle_open_id' in d:
            o.oversea_settle_open_id = d['oversea_settle_open_id']
        if 'qualifications' in d:
            o.qualifications = d['qualifications']
        if 'service' in d:
            o.service = d['service']
        if 'service_phone' in d:
            o.service_phone = d['service_phone']
        if 'sign_time_with_isv' in d:
            o.sign_time_with_isv = d['sign_time_with_isv']
        if 'sites' in d:
            o.sites = d['sites']
        if 'smid' in d:
            o.smid = d['smid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipaySecurityRiskPolicyRdsQueryModel(object):

    def __init__(self):
        self._rds_params = None

    @property
    def rds_params(self):
        return self._rds_params

    @rds_params.setter
    def rds_params(self, value):
        self._rds_params = value


    def to_alipay_dict(self):
        params = dict()
        if self.rds_params:
            if hasattr(self.rds_params, 'to_alipay_dict'):
                params['rds_params'] = self.rds_params.to_alipay_dict()
            else:
                params['rds_params'] = self.rds_params
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipaySecurityRiskPolicyRdsQueryModel()
        if 'rds_params' in d:
            o.rds_params = d['rds_params']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SettleEntity(object):

    def __init__(self):
        self._settle_entity_id = None
        self._settle_entity_type = None

    @property
    def settle_entity_id(self):
        return self._settle_entity_id

    @settle_entity_id.setter
    def settle_entity_id(self, value):
        self._settle_entity_id = value
    @property
    def settle_entity_type(self):
        return self._settle_entity_type

    @settle_entity_type.setter
    def settle_entity_type(self, value):
        self._settle_entity_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.settle_entity_id:
            if hasattr(self.settle_entity_id, 'to_alipay_dict'):
                params['settle_entity_id'] = self.settle_entity_id.to_alipay_dict()
            else:
                params['settle_entity_id'] = self.settle_entity_id
        if self.settle_entity_type:
            if hasattr(self.settle_entity_type, 'to_alipay_dict'):
                params['settle_entity_type'] = self.settle_entity_type.to_alipay_dict()
            else:
                params['settle_entity_type'] = self.settle_entity_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SettleEntity()
        if 'settle_entity_id' in d:
            o.settle_entity_id = d['settle_entity_id']
        if 'settle_entity_type' in d:
            o.settle_entity_type = d['settle_entity_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenIotbpaasLavidabillsumQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenIotbpaasLavidabillsumQueryResponse, self).__init__()
        self._mercht_disc_amt = None
        self._order_amt = None
        self._recv_amt = None
        self._recv_cnt = None
        self._refund_amt = None
        self._refund_cnt = None

    @property
    def mercht_disc_amt(self):
        return self._mercht_disc_amt

    @mercht_disc_amt.setter
    def mercht_disc_amt(self, value):
        self._mercht_disc_amt = value
    @property
    def order_amt(self):
        return self._order_amt

    @order_amt.setter
    def order_amt(self, value):
        self._order_amt = value
    @property
    def recv_amt(self):
        return self._recv_amt

    @recv_amt.setter
    def recv_amt(self, value):
        self._recv_amt = value
    @property
    def recv_cnt(self):
        return self._recv_cnt

    @recv_cnt.setter
    def recv_cnt(self, value):
        self._recv_cnt = value
    @property
    def refund_amt(self):
        return self._refund_amt

    @refund_amt.setter
    def refund_amt(self, value):
        self._refund_amt = value
    @property
    def refund_cnt(self):
        return self._refund_cnt

    @refund_cnt.setter
    def refund_cnt(self, value):
        self._refund_cnt = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenIotbpaasLavidabillsumQueryResponse, self).parse_response_content(response_content)
        if 'mercht_disc_amt' in response:
            self.mercht_disc_amt = response['mercht_disc_amt']
        if 'order_amt' in response:
            self.order_amt = response['order_amt']
        if 'recv_amt' in response:
            self.recv_amt = response['recv_amt']
        if 'recv_cnt' in response:
            self.recv_cnt = response['recv_cnt']
        if 'refund_amt' in response:
            self.refund_amt = response['refund_amt']
        if 'refund_cnt' in response:
            self.refund_cnt = response['refund_cnt']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenMiniCloudFileQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenMiniCloudFileQueryResponse, self).__init__()
        self._absolute_path = None
        self._cloud_id = None
        self._creator = None
        self._download_url = None
        self._enable = None
        self._file_id = None
        self._file_name = None
        self._file_type = None
        self._path = None

    @property
    def absolute_path(self):
        return self._absolute_path

    @absolute_path.setter
    def absolute_path(self, value):
        self._absolute_path = value
    @property
    def cloud_id(self):
        return self._cloud_id

    @cloud_id.setter
    def cloud_id(self, value):
        self._cloud_id = value
    @property
    def creator(self):
        return self._creator

    @creator.setter
    def creator(self, value):
        self._creator = value
    @property
    def download_url(self):
        return self._download_url

    @download_url.setter
    def download_url(self, value):
        self._download_url = value
    @property
    def enable(self):
        return self._enable

    @enable.setter
    def enable(self, value):
        self._enable = value
    @property
    def file_id(self):
        return self._file_id

    @file_id.setter
    def file_id(self, value):
        self._file_id = value
    @property
    def file_name(self):
        return self._file_name

    @file_name.setter
    def file_name(self, value):
        self._file_name = value
    @property
    def file_type(self):
        return self._file_type

    @file_type.setter
    def file_type(self, value):
        self._file_type = value
    @property
    def path(self):
        return self._path

    @path.setter
    def path(self, value):
        self._path = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenMiniCloudFileQueryResponse, self).parse_response_content(response_content)
        if 'absolute_path' in response:
            self.absolute_path = response['absolute_path']
        if 'cloud_id' in response:
            self.cloud_id = response['cloud_id']
        if 'creator' in response:
            self.creator = response['creator']
        if 'download_url' in response:
            self.download_url = response['download_url']
        if 'enable' in response:
            self.enable = response['enable']
        if 'file_id' in response:
            self.file_id = response['file_id']
        if 'file_name' in response:
            self.file_name = response['file_name']
        if 'file_type' in response:
            self.file_type = response['file_type']
        if 'path' in response:
            self.path = response['path']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.JourneyLocation import JourneyLocation
from alipay.aop.api.domain.JourneyLocation import JourneyLocation
from alipay.aop.api.domain.OrderExtInfo import OrderExtInfo
from alipay.aop.api.domain.FunctionalService import FunctionalService
from alipay.aop.api.domain.JourneyLocation import JourneyLocation
from alipay.aop.api.domain.SeatInfo import SeatInfo
from alipay.aop.api.domain.OrderParticipantInfo import OrderParticipantInfo
from alipay.aop.api.domain.OrderShopInfo import OrderShopInfo
from alipay.aop.api.domain.UserInfomation import UserInfomation
from alipay.aop.api.domain.OrderVehicleInfo import OrderVehicleInfo


class TicketOrderInfo(object):

    def __init__(self):
        self._arrival = None
        self._content = None
        self._departure = None
        self._effective_num = None
        self._end_time = None
        self._ext_info = None
        self._face_value = None
        self._functional_services = None
        self._invalid_reason = None
        self._locations = None
        self._merchant_ticket_no = None
        self._seat_infos = None
        self._service_provider = None
        self._shops = None
        self._start_time = None
        self._status = None
        self._ticket_create_time = None
        self._ticket_modify_time = None
        self._ticket_num = None
        self._ticket_users = None
        self._title = None
        self._vehicle_info = None

    @property
    def arrival(self):
        return self._arrival

    @arrival.setter
    def arrival(self, value):
        if isinstance(value, JourneyLocation):
            self._arrival = value
        else:
            self._arrival = JourneyLocation.from_alipay_dict(value)
    @property
    def content(self):
        return self._content

    @content.setter
    def content(self, value):
        self._content = value
    @property
    def departure(self):
        return self._departure

    @departure.setter
    def departure(self, value):
        if isinstance(value, JourneyLocation):
            self._departure = value
        else:
            self._departure = JourneyLocation.from_alipay_dict(value)
    @property
    def effective_num(self):
        return self._effective_num

    @effective_num.setter
    def effective_num(self, value):
        self._effective_num = value
    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        if isinstance(value, list):
            self._ext_info = list()
            for i in value:
                if isinstance(i, OrderExtInfo):
                    self._ext_info.append(i)
                else:
                    self._ext_info.append(OrderExtInfo.from_alipay_dict(i))
    @property
    def face_value(self):
        return self._face_value

    @face_value.setter
    def face_value(self, value):
        self._face_value = value
    @property
    def functional_services(self):
        return self._functional_services

    @functional_services.setter
    def functional_services(self, value):
        if isinstance(value, list):
            self._functional_services = list()
            for i in value:
                if isinstance(i, FunctionalService):
                    self._functional_services.append(i)
                else:
                    self._functional_services.append(FunctionalService.from_alipay_dict(i))
    @property
    def invalid_reason(self):
        return self._invalid_reason

    @invalid_reason.setter
    def invalid_reason(self, value):
        self._invalid_reason = value
    @property
    def locations(self):
        return self._locations

    @locations.setter
    def locations(self, value):
        if isinstance(value, list):
            self._locations = list()
            for i in value:
                if isinstance(i, JourneyLocation):
                    self._locations.append(i)
                else:
                    self._locations.append(JourneyLocation.from_alipay_dict(i))
    @property
    def merchant_ticket_no(self):
        return self._merchant_ticket_no

    @merchant_ticket_no.setter
    def merchant_ticket_no(self, value):
        self._merchant_ticket_no = value
    @property
    def seat_infos(self):
        return self._seat_infos

    @seat_infos.setter
    def seat_infos(self, value):
        if isinstance(value, list):
            self._seat_infos = list()
            for i in value:
                if isinstance(i, SeatInfo):
                    self._seat_infos.append(i)
                else:
                    self._seat_infos.append(SeatInfo.from_alipay_dict(i))
    @property
    def service_provider(self):
        return self._service_provider

    @service_provider.setter
    def service_provider(self, value):
        if isinstance(value, OrderParticipantInfo):
            self._service_provider = value
        else:
            self._service_provider = OrderParticipantInfo.from_alipay_dict(value)
    @property
    def shops(self):
        return self._shops

    @shops.setter
    def shops(self, value):
        if isinstance(value, list):
            self._shops = list()
            for i in value:
                if isinstance(i, OrderShopInfo):
                    self._shops.append(i)
                else:
                    self._shops.append(OrderShopInfo.from_alipay_dict(i))
    @property
    def start_time(self):
        return self._start_time

    @start_time.setter
    def start_time(self, value):
        self._start_time = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def ticket_create_time(self):
        return self._ticket_create_time

    @ticket_create_time.setter
    def ticket_create_time(self, value):
        self._ticket_create_time = value
    @property
    def ticket_modify_time(self):
        return self._ticket_modify_time

    @ticket_modify_time.setter
    def ticket_modify_time(self, value):
        self._ticket_modify_time = value
    @property
    def ticket_num(self):
        return self._ticket_num

    @ticket_num.setter
    def ticket_num(self, value):
        self._ticket_num = value
    @property
    def ticket_users(self):
        return self._ticket_users

    @ticket_users.setter
    def ticket_users(self, value):
        if isinstance(value, list):
            self._ticket_users = list()
            for i in value:
                if isinstance(i, UserInfomation):
                    self._ticket_users.append(i)
                else:
                    self._ticket_users.append(UserInfomation.from_alipay_dict(i))
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value
    @property
    def vehicle_info(self):
        return self._vehicle_info

    @vehicle_info.setter
    def vehicle_info(self, value):
        if isinstance(value, OrderVehicleInfo):
            self._vehicle_info = value
        else:
            self._vehicle_info = OrderVehicleInfo.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.arrival:
            if hasattr(self.arrival, 'to_alipay_dict'):
                params['arrival'] = self.arrival.to_alipay_dict()
            else:
                params['arrival'] = self.arrival
        if self.content:
            if hasattr(self.content, 'to_alipay_dict'):
                params['content'] = self.content.to_alipay_dict()
            else:
                params['content'] = self.content
        if self.departure:
            if hasattr(self.departure, 'to_alipay_dict'):
                params['departure'] = self.departure.to_alipay_dict()
            else:
                params['departure'] = self.departure
        if self.effective_num:
            if hasattr(self.effective_num, 'to_alipay_dict'):
                params['effective_num'] = self.effective_num.to_alipay_dict()
            else:
                params['effective_num'] = self.effective_num
        if self.end_time:
            if hasattr(self.end_time, 'to_alipay_dict'):
                params['end_time'] = self.end_time.to_alipay_dict()
            else:
                params['end_time'] = self.end_time
        if self.ext_info:
            if isinstance(self.ext_info, list):
                for i in range(0, len(self.ext_info)):
                    element = self.ext_info[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.ext_info[i] = element.to_alipay_dict()
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.face_value:
            if hasattr(self.face_value, 'to_alipay_dict'):
                params['face_value'] = self.face_value.to_alipay_dict()
            else:
                params['face_value'] = self.face_value
        if self.functional_services:
            if isinstance(self.functional_services, list):
                for i in range(0, len(self.functional_services)):
                    element = self.functional_services[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.functional_services[i] = element.to_alipay_dict()
            if hasattr(self.functional_services, 'to_alipay_dict'):
                params['functional_services'] = self.functional_services.to_alipay_dict()
            else:
                params['functional_services'] = self.functional_services
        if self.invalid_reason:
            if hasattr(self.invalid_reason, 'to_alipay_dict'):
                params['invalid_reason'] = self.invalid_reason.to_alipay_dict()
            else:
                params['invalid_reason'] = self.invalid_reason
        if self.locations:
            if isinstance(self.locations, list):
                for i in range(0, len(self.locations)):
                    element = self.locations[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.locations[i] = element.to_alipay_dict()
            if hasattr(self.locations, 'to_alipay_dict'):
                params['locations'] = self.locations.to_alipay_dict()
            else:
                params['locations'] = self.locations
        if self.merchant_ticket_no:
            if hasattr(self.merchant_ticket_no, 'to_alipay_dict'):
                params['merchant_ticket_no'] = self.merchant_ticket_no.to_alipay_dict()
            else:
                params['merchant_ticket_no'] = self.merchant_ticket_no
        if self.seat_infos:
            if isinstance(self.seat_infos, list):
                for i in range(0, len(self.seat_infos)):
                    element = self.seat_infos[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.seat_infos[i] = element.to_alipay_dict()
            if hasattr(self.seat_infos, 'to_alipay_dict'):
                params['seat_infos'] = self.seat_infos.to_alipay_dict()
            else:
                params['seat_infos'] = self.seat_infos
        if self.service_provider:
            if hasattr(self.service_provider, 'to_alipay_dict'):
                params['service_provider'] = self.service_provider.to_alipay_dict()
            else:
                params['service_provider'] = self.service_provider
        if self.shops:
            if isinstance(self.shops, list):
                for i in range(0, len(self.shops)):
                    element = self.shops[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.shops[i] = element.to_alipay_dict()
            if hasattr(self.shops, 'to_alipay_dict'):
                params['shops'] = self.shops.to_alipay_dict()
            else:
                params['shops'] = self.shops
        if self.start_time:
            if hasattr(self.start_time, 'to_alipay_dict'):
                params['start_time'] = self.start_time.to_alipay_dict()
            else:
                params['start_time'] = self.start_time
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.ticket_create_time:
            if hasattr(self.ticket_create_time, 'to_alipay_dict'):
                params['ticket_create_time'] = self.ticket_create_time.to_alipay_dict()
            else:
                params['ticket_create_time'] = self.ticket_create_time
        if self.ticket_modify_time:
            if hasattr(self.ticket_modify_time, 'to_alipay_dict'):
                params['ticket_modify_time'] = self.ticket_modify_time.to_alipay_dict()
            else:
                params['ticket_modify_time'] = self.ticket_modify_time
        if self.ticket_num:
            if hasattr(self.ticket_num, 'to_alipay_dict'):
                params['ticket_num'] = self.ticket_num.to_alipay_dict()
            else:
                params['ticket_num'] = self.ticket_num
        if self.ticket_users:
            if isinstance(self.ticket_users, list):
                for i in range(0, len(self.ticket_users)):
                    element = self.ticket_users[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.ticket_users[i] = element.to_alipay_dict()
            if hasattr(self.ticket_users, 'to_alipay_dict'):
                params['ticket_users'] = self.ticket_users.to_alipay_dict()
            else:
                params['ticket_users'] = self.ticket_users
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        if self.vehicle_info:
            if hasattr(self.vehicle_info, 'to_alipay_dict'):
                params['vehicle_info'] = self.vehicle_info.to_alipay_dict()
            else:
                params['vehicle_info'] = self.vehicle_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TicketOrderInfo()
        if 'arrival' in d:
            o.arrival = d['arrival']
        if 'content' in d:
            o.content = d['content']
        if 'departure' in d:
            o.departure = d['departure']
        if 'effective_num' in d:
            o.effective_num = d['effective_num']
        if 'end_time' in d:
            o.end_time = d['end_time']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'face_value' in d:
            o.face_value = d['face_value']
        if 'functional_services' in d:
            o.functional_services = d['functional_services']
        if 'invalid_reason' in d:
            o.invalid_reason = d['invalid_reason']
        if 'locations' in d:
            o.locations = d['locations']
        if 'merchant_ticket_no' in d:
            o.merchant_ticket_no = d['merchant_ticket_no']
        if 'seat_infos' in d:
            o.seat_infos = d['seat_infos']
        if 'service_provider' in d:
            o.service_provider = d['service_provider']
        if 'shops' in d:
            o.shops = d['shops']
        if 'start_time' in d:
            o.start_time = d['start_time']
        if 'status' in d:
            o.status = d['status']
        if 'ticket_create_time' in d:
            o.ticket_create_time = d['ticket_create_time']
        if 'ticket_modify_time' in d:
            o.ticket_modify_time = d['ticket_modify_time']
        if 'ticket_num' in d:
            o.ticket_num = d['ticket_num']
        if 'ticket_users' in d:
            o.ticket_users = d['ticket_users']
        if 'title' in d:
            o.title = d['title']
        if 'vehicle_info' in d:
            o.vehicle_info = d['vehicle_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AnttechBlockchainSignIndexCreateModel(object):

    def __init__(self):
        self._app_name = None
        self._biz_corp = None
        self._biz_from = None
        self._biz_scene = None
        self._biz_unique_key = None
        self._open_id = None
        self._principal_id = None
        self._principal_type = None
        self._sign_version = None
        self._tenant = None
        self._valid_end_date = None
        self._valid_start_date = None

    @property
    def app_name(self):
        return self._app_name

    @app_name.setter
    def app_name(self, value):
        self._app_name = value
    @property
    def biz_corp(self):
        return self._biz_corp

    @biz_corp.setter
    def biz_corp(self, value):
        self._biz_corp = value
    @property
    def biz_from(self):
        return self._biz_from

    @biz_from.setter
    def biz_from(self, value):
        self._biz_from = value
    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def biz_unique_key(self):
        return self._biz_unique_key

    @biz_unique_key.setter
    def biz_unique_key(self, value):
        self._biz_unique_key = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def principal_id(self):
        return self._principal_id

    @principal_id.setter
    def principal_id(self, value):
        self._principal_id = value
    @property
    def principal_type(self):
        return self._principal_type

    @principal_type.setter
    def principal_type(self, value):
        self._principal_type = value
    @property
    def sign_version(self):
        return self._sign_version

    @sign_version.setter
    def sign_version(self, value):
        self._sign_version = value
    @property
    def tenant(self):
        return self._tenant

    @tenant.setter
    def tenant(self, value):
        self._tenant = value
    @property
    def valid_end_date(self):
        return self._valid_end_date

    @valid_end_date.setter
    def valid_end_date(self, value):
        self._valid_end_date = value
    @property
    def valid_start_date(self):
        return self._valid_start_date

    @valid_start_date.setter
    def valid_start_date(self, value):
        self._valid_start_date = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_name:
            if hasattr(self.app_name, 'to_alipay_dict'):
                params['app_name'] = self.app_name.to_alipay_dict()
            else:
                params['app_name'] = self.app_name
        if self.biz_corp:
            if hasattr(self.biz_corp, 'to_alipay_dict'):
                params['biz_corp'] = self.biz_corp.to_alipay_dict()
            else:
                params['biz_corp'] = self.biz_corp
        if self.biz_from:
            if hasattr(self.biz_from, 'to_alipay_dict'):
                params['biz_from'] = self.biz_from.to_alipay_dict()
            else:
                params['biz_from'] = self.biz_from
        if self.biz_scene:
            if hasattr(self.biz_scene, 'to_alipay_dict'):
                params['biz_scene'] = self.biz_scene.to_alipay_dict()
            else:
                params['biz_scene'] = self.biz_scene
        if self.biz_unique_key:
            if hasattr(self.biz_unique_key, 'to_alipay_dict'):
                params['biz_unique_key'] = self.biz_unique_key.to_alipay_dict()
            else:
                params['biz_unique_key'] = self.biz_unique_key
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.principal_id:
            if hasattr(self.principal_id, 'to_alipay_dict'):
                params['principal_id'] = self.principal_id.to_alipay_dict()
            else:
                params['principal_id'] = self.principal_id
        if self.principal_type:
            if hasattr(self.principal_type, 'to_alipay_dict'):
                params['principal_type'] = self.principal_type.to_alipay_dict()
            else:
                params['principal_type'] = self.principal_type
        if self.sign_version:
            if hasattr(self.sign_version, 'to_alipay_dict'):
                params['sign_version'] = self.sign_version.to_alipay_dict()
            else:
                params['sign_version'] = self.sign_version
        if self.tenant:
            if hasattr(self.tenant, 'to_alipay_dict'):
                params['tenant'] = self.tenant.to_alipay_dict()
            else:
                params['tenant'] = self.tenant
        if self.valid_end_date:
            if hasattr(self.valid_end_date, 'to_alipay_dict'):
                params['valid_end_date'] = self.valid_end_date.to_alipay_dict()
            else:
                params['valid_end_date'] = self.valid_end_date
        if self.valid_start_date:
            if hasattr(self.valid_start_date, 'to_alipay_dict'):
                params['valid_start_date'] = self.valid_start_date.to_alipay_dict()
            else:
                params['valid_start_date'] = self.valid_start_date
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AnttechBlockchainSignIndexCreateModel()
        if 'app_name' in d:
            o.app_name = d['app_name']
        if 'biz_corp' in d:
            o.biz_corp = d['biz_corp']
        if 'biz_from' in d:
            o.biz_from = d['biz_from']
        if 'biz_scene' in d:
            o.biz_scene = d['biz_scene']
        if 'biz_unique_key' in d:
            o.biz_unique_key = d['biz_unique_key']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'principal_id' in d:
            o.principal_id = d['principal_id']
        if 'principal_type' in d:
            o.principal_type = d['principal_type']
        if 'sign_version' in d:
            o.sign_version = d['sign_version']
        if 'tenant' in d:
            o.tenant = d['tenant']
        if 'valid_end_date' in d:
            o.valid_end_date = d['valid_end_date']
        if 'valid_start_date' in d:
            o.valid_start_date = d['valid_start_date']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CPBillResultSet(object):

    def __init__(self):
        self._acct_period = None
        self._bill_entry_amount = None
        self._bill_entry_id = None
        self._cost_type = None
        self._deadline = None
        self._out_room_id = None
        self._release_day = None
        self._room_address = None
        self._status = None

    @property
    def acct_period(self):
        return self._acct_period

    @acct_period.setter
    def acct_period(self, value):
        self._acct_period = value
    @property
    def bill_entry_amount(self):
        return self._bill_entry_amount

    @bill_entry_amount.setter
    def bill_entry_amount(self, value):
        self._bill_entry_amount = value
    @property
    def bill_entry_id(self):
        return self._bill_entry_id

    @bill_entry_id.setter
    def bill_entry_id(self, value):
        self._bill_entry_id = value
    @property
    def cost_type(self):
        return self._cost_type

    @cost_type.setter
    def cost_type(self, value):
        self._cost_type = value
    @property
    def deadline(self):
        return self._deadline

    @deadline.setter
    def deadline(self, value):
        self._deadline = value
    @property
    def out_room_id(self):
        return self._out_room_id

    @out_room_id.setter
    def out_room_id(self, value):
        self._out_room_id = value
    @property
    def release_day(self):
        return self._release_day

    @release_day.setter
    def release_day(self, value):
        self._release_day = value
    @property
    def room_address(self):
        return self._room_address

    @room_address.setter
    def room_address(self, value):
        self._room_address = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.acct_period:
            if hasattr(self.acct_period, 'to_alipay_dict'):
                params['acct_period'] = self.acct_period.to_alipay_dict()
            else:
                params['acct_period'] = self.acct_period
        if self.bill_entry_amount:
            if hasattr(self.bill_entry_amount, 'to_alipay_dict'):
                params['bill_entry_amount'] = self.bill_entry_amount.to_alipay_dict()
            else:
                params['bill_entry_amount'] = self.bill_entry_amount
        if self.bill_entry_id:
            if hasattr(self.bill_entry_id, 'to_alipay_dict'):
                params['bill_entry_id'] = self.bill_entry_id.to_alipay_dict()
            else:
                params['bill_entry_id'] = self.bill_entry_id
        if self.cost_type:
            if hasattr(self.cost_type, 'to_alipay_dict'):
                params['cost_type'] = self.cost_type.to_alipay_dict()
            else:
                params['cost_type'] = self.cost_type
        if self.deadline:
            if hasattr(self.deadline, 'to_alipay_dict'):
                params['deadline'] = self.deadline.to_alipay_dict()
            else:
                params['deadline'] = self.deadline
        if self.out_room_id:
            if hasattr(self.out_room_id, 'to_alipay_dict'):
                params['out_room_id'] = self.out_room_id.to_alipay_dict()
            else:
                params['out_room_id'] = self.out_room_id
        if self.release_day:
            if hasattr(self.release_day, 'to_alipay_dict'):
                params['release_day'] = self.release_day.to_alipay_dict()
            else:
                params['release_day'] = self.release_day
        if self.room_address:
            if hasattr(self.room_address, 'to_alipay_dict'):
                params['room_address'] = self.room_address.to_alipay_dict()
            else:
                params['room_address'] = self.room_address
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CPBillResultSet()
        if 'acct_period' in d:
            o.acct_period = d['acct_period']
        if 'bill_entry_amount' in d:
            o.bill_entry_amount = d['bill_entry_amount']
        if 'bill_entry_id' in d:
            o.bill_entry_id = d['bill_entry_id']
        if 'cost_type' in d:
            o.cost_type = d['cost_type']
        if 'deadline' in d:
            o.deadline = d['deadline']
        if 'out_room_id' in d:
            o.out_room_id = d['out_room_id']
        if 'release_day' in d:
            o.release_day = d['release_day']
        if 'room_address' in d:
            o.room_address = d['room_address']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.SlmServiceAtomicInfoVO import SlmServiceAtomicInfoVO


class AlipayOpenMiniAutocheckStepGetResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenMiniAutocheckStepGetResponse, self).__init__()
        self._slm_service_atomic_info = None

    @property
    def slm_service_atomic_info(self):
        return self._slm_service_atomic_info

    @slm_service_atomic_info.setter
    def slm_service_atomic_info(self, value):
        if isinstance(value, list):
            self._slm_service_atomic_info = list()
            for i in value:
                if isinstance(i, SlmServiceAtomicInfoVO):
                    self._slm_service_atomic_info.append(i)
                else:
                    self._slm_service_atomic_info.append(SlmServiceAtomicInfoVO.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayOpenMiniAutocheckStepGetResponse, self).parse_response_content(response_content)
        if 'slm_service_atomic_info' in response:
            self.slm_service_atomic_info = response['slm_service_atomic_info']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZMGOQuitConfig(object):

    def __init__(self):
        self._quit_desc = None
        self._quit_jump_url = None
        self._quit_type = None

    @property
    def quit_desc(self):
        return self._quit_desc

    @quit_desc.setter
    def quit_desc(self, value):
        self._quit_desc = value
    @property
    def quit_jump_url(self):
        return self._quit_jump_url

    @quit_jump_url.setter
    def quit_jump_url(self, value):
        self._quit_jump_url = value
    @property
    def quit_type(self):
        return self._quit_type

    @quit_type.setter
    def quit_type(self, value):
        self._quit_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.quit_desc:
            if hasattr(self.quit_desc, 'to_alipay_dict'):
                params['quit_desc'] = self.quit_desc.to_alipay_dict()
            else:
                params['quit_desc'] = self.quit_desc
        if self.quit_jump_url:
            if hasattr(self.quit_jump_url, 'to_alipay_dict'):
                params['quit_jump_url'] = self.quit_jump_url.to_alipay_dict()
            else:
                params['quit_jump_url'] = self.quit_jump_url
        if self.quit_type:
            if hasattr(self.quit_type, 'to_alipay_dict'):
                params['quit_type'] = self.quit_type.to_alipay_dict()
            else:
                params['quit_type'] = self.quit_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZMGOQuitConfig()
        if 'quit_desc' in d:
            o.quit_desc = d['quit_desc']
        if 'quit_jump_url' in d:
            o.quit_jump_url = d['quit_jump_url']
        if 'quit_type' in d:
            o.quit_type = d['quit_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ProductProvider import ProductProvider


class SaleProduct(object):

    def __init__(self):
        self._channel_type = None
        self._id = None
        self._market_price = None
        self._product_provider = None
        self._sale_price = None
        self._status = None

    @property
    def channel_type(self):
        return self._channel_type

    @channel_type.setter
    def channel_type(self, value):
        self._channel_type = value
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def market_price(self):
        return self._market_price

    @market_price.setter
    def market_price(self, value):
        self._market_price = value
    @property
    def product_provider(self):
        return self._product_provider

    @product_provider.setter
    def product_provider(self, value):
        if isinstance(value, ProductProvider):
            self._product_provider = value
        else:
            self._product_provider = ProductProvider.from_alipay_dict(value)
    @property
    def sale_price(self):
        return self._sale_price

    @sale_price.setter
    def sale_price(self, value):
        self._sale_price = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.channel_type:
            if hasattr(self.channel_type, 'to_alipay_dict'):
                params['channel_type'] = self.channel_type.to_alipay_dict()
            else:
                params['channel_type'] = self.channel_type
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.market_price:
            if hasattr(self.market_price, 'to_alipay_dict'):
                params['market_price'] = self.market_price.to_alipay_dict()
            else:
                params['market_price'] = self.market_price
        if self.product_provider:
            if hasattr(self.product_provider, 'to_alipay_dict'):
                params['product_provider'] = self.product_provider.to_alipay_dict()
            else:
                params['product_provider'] = self.product_provider
        if self.sale_price:
            if hasattr(self.sale_price, 'to_alipay_dict'):
                params['sale_price'] = self.sale_price.to_alipay_dict()
            else:
                params['sale_price'] = self.sale_price
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SaleProduct()
        if 'channel_type' in d:
            o.channel_type = d['channel_type']
        if 'id' in d:
            o.id = d['id']
        if 'market_price' in d:
            o.market_price = d['market_price']
        if 'product_provider' in d:
            o.product_provider = d['product_provider']
        if 'sale_price' in d:
            o.sale_price = d['sale_price']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayCommerceIotSdarttoolMessageQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceIotSdarttoolMessageQueryResponse, self).__init__()
        self._consume_err_code = None
        self._consume_err_msg = None
        self._consume_state = None
        self._deliver_cnt = None
        self._deliver_status = None
        self._last_deliver_at = None
        self._msg_ack_time = None
        self._msg_bida = None
        self._msg_expire_time = None
        self._msg_gmt_create = None
        self._msg_priority = None

    @property
    def consume_err_code(self):
        return self._consume_err_code

    @consume_err_code.setter
    def consume_err_code(self, value):
        self._consume_err_code = value
    @property
    def consume_err_msg(self):
        return self._consume_err_msg

    @consume_err_msg.setter
    def consume_err_msg(self, value):
        self._consume_err_msg = value
    @property
    def consume_state(self):
        return self._consume_state

    @consume_state.setter
    def consume_state(self, value):
        self._consume_state = value
    @property
    def deliver_cnt(self):
        return self._deliver_cnt

    @deliver_cnt.setter
    def deliver_cnt(self, value):
        self._deliver_cnt = value
    @property
    def deliver_status(self):
        return self._deliver_status

    @deliver_status.setter
    def deliver_status(self, value):
        self._deliver_status = value
    @property
    def last_deliver_at(self):
        return self._last_deliver_at

    @last_deliver_at.setter
    def last_deliver_at(self, value):
        self._last_deliver_at = value
    @property
    def msg_ack_time(self):
        return self._msg_ack_time

    @msg_ack_time.setter
    def msg_ack_time(self, value):
        self._msg_ack_time = value
    @property
    def msg_bida(self):
        return self._msg_bida

    @msg_bida.setter
    def msg_bida(self, value):
        self._msg_bida = value
    @property
    def msg_expire_time(self):
        return self._msg_expire_time

    @msg_expire_time.setter
    def msg_expire_time(self, value):
        self._msg_expire_time = value
    @property
    def msg_gmt_create(self):
        return self._msg_gmt_create

    @msg_gmt_create.setter
    def msg_gmt_create(self, value):
        self._msg_gmt_create = value
    @property
    def msg_priority(self):
        return self._msg_priority

    @msg_priority.setter
    def msg_priority(self, value):
        self._msg_priority = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceIotSdarttoolMessageQueryResponse, self).parse_response_content(response_content)
        if 'consume_err_code' in response:
            self.consume_err_code = response['consume_err_code']
        if 'consume_err_msg' in response:
            self.consume_err_msg = response['consume_err_msg']
        if 'consume_state' in response:
            self.consume_state = response['consume_state']
        if 'deliver_cnt' in response:
            self.deliver_cnt = response['deliver_cnt']
        if 'deliver_status' in response:
            self.deliver_status = response['deliver_status']
        if 'last_deliver_at' in response:
            self.last_deliver_at = response['last_deliver_at']
        if 'msg_ack_time' in response:
            self.msg_ack_time = response['msg_ack_time']
        if 'msg_bida' in response:
            self.msg_bida = response['msg_bida']
        if 'msg_expire_time' in response:
            self.msg_expire_time = response['msg_expire_time']
        if 'msg_gmt_create' in response:
            self.msg_gmt_create = response['msg_gmt_create']
        if 'msg_priority' in response:
            self.msg_priority = response['msg_priority']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.VoucherBill import VoucherBill


class AlipayMarketingVoucherBillQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMarketingVoucherBillQueryResponse, self).__init__()
        self._current_page = None
        self._items_per_page = None
        self._total_items = None
        self._total_pages = None
        self._voucher_bills = None

    @property
    def current_page(self):
        return self._current_page

    @current_page.setter
    def current_page(self, value):
        self._current_page = value
    @property
    def items_per_page(self):
        return self._items_per_page

    @items_per_page.setter
    def items_per_page(self, value):
        self._items_per_page = value
    @property
    def total_items(self):
        return self._total_items

    @total_items.setter
    def total_items(self, value):
        self._total_items = value
    @property
    def total_pages(self):
        return self._total_pages

    @total_pages.setter
    def total_pages(self, value):
        self._total_pages = value
    @property
    def voucher_bills(self):
        return self._voucher_bills

    @voucher_bills.setter
    def voucher_bills(self, value):
        if isinstance(value, list):
            self._voucher_bills = list()
            for i in value:
                if isinstance(i, VoucherBill):
                    self._voucher_bills.append(i)
                else:
                    self._voucher_bills.append(VoucherBill.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayMarketingVoucherBillQueryResponse, self).parse_response_content(response_content)
        if 'current_page' in response:
            self.current_page = response['current_page']
        if 'items_per_page' in response:
            self.items_per_page = response['items_per_page']
        if 'total_items' in response:
            self.total_items = response['total_items']
        if 'total_pages' in response:
            self.total_pages = response['total_pages']
        if 'voucher_bills' in response:
            self.voucher_bills = response['voucher_bills']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenAppAppcontentInternalQueryModel(object):

    def __init__(self):
        self._page_num = None
        self._page_size = None
        self._pid = None
        self._query_mode = None
        self._ref_app_id = None
        self._request_system = None
        self._service_code_list = None

    @property
    def page_num(self):
        return self._page_num

    @page_num.setter
    def page_num(self, value):
        self._page_num = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def pid(self):
        return self._pid

    @pid.setter
    def pid(self, value):
        self._pid = value
    @property
    def query_mode(self):
        return self._query_mode

    @query_mode.setter
    def query_mode(self, value):
        self._query_mode = value
    @property
    def ref_app_id(self):
        return self._ref_app_id

    @ref_app_id.setter
    def ref_app_id(self, value):
        self._ref_app_id = value
    @property
    def request_system(self):
        return self._request_system

    @request_system.setter
    def request_system(self, value):
        self._request_system = value
    @property
    def service_code_list(self):
        return self._service_code_list

    @service_code_list.setter
    def service_code_list(self, value):
        if isinstance(value, list):
            self._service_code_list = list()
            for i in value:
                self._service_code_list.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.page_num:
            if hasattr(self.page_num, 'to_alipay_dict'):
                params['page_num'] = self.page_num.to_alipay_dict()
            else:
                params['page_num'] = self.page_num
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.pid:
            if hasattr(self.pid, 'to_alipay_dict'):
                params['pid'] = self.pid.to_alipay_dict()
            else:
                params['pid'] = self.pid
        if self.query_mode:
            if hasattr(self.query_mode, 'to_alipay_dict'):
                params['query_mode'] = self.query_mode.to_alipay_dict()
            else:
                params['query_mode'] = self.query_mode
        if self.ref_app_id:
            if hasattr(self.ref_app_id, 'to_alipay_dict'):
                params['ref_app_id'] = self.ref_app_id.to_alipay_dict()
            else:
                params['ref_app_id'] = self.ref_app_id
        if self.request_system:
            if hasattr(self.request_system, 'to_alipay_dict'):
                params['request_system'] = self.request_system.to_alipay_dict()
            else:
                params['request_system'] = self.request_system
        if self.service_code_list:
            if isinstance(self.service_code_list, list):
                for i in range(0, len(self.service_code_list)):
                    element = self.service_code_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.service_code_list[i] = element.to_alipay_dict()
            if hasattr(self.service_code_list, 'to_alipay_dict'):
                params['service_code_list'] = self.service_code_list.to_alipay_dict()
            else:
                params['service_code_list'] = self.service_code_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenAppAppcontentInternalQueryModel()
        if 'page_num' in d:
            o.page_num = d['page_num']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'pid' in d:
            o.pid = d['pid']
        if 'query_mode' in d:
            o.query_mode = d['query_mode']
        if 'ref_app_id' in d:
            o.ref_app_id = d['ref_app_id']
        if 'request_system' in d:
            o.request_system = d['request_system']
        if 'service_code_list' in d:
            o.service_code_list = d['service_code_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipaySocialBaseChatSendModel(object):

    def __init__(self):
        self._biz_memo = None
        self._client_msg_id = None
        self._link = None
        self._receiver_id = None
        self._receiver_usertype = None
        self._template_data = None
        self._template_type = None

    @property
    def biz_memo(self):
        return self._biz_memo

    @biz_memo.setter
    def biz_memo(self, value):
        self._biz_memo = value
    @property
    def client_msg_id(self):
        return self._client_msg_id

    @client_msg_id.setter
    def client_msg_id(self, value):
        self._client_msg_id = value
    @property
    def link(self):
        return self._link

    @link.setter
    def link(self, value):
        self._link = value
    @property
    def receiver_id(self):
        return self._receiver_id

    @receiver_id.setter
    def receiver_id(self, value):
        self._receiver_id = value
    @property
    def receiver_usertype(self):
        return self._receiver_usertype

    @receiver_usertype.setter
    def receiver_usertype(self, value):
        self._receiver_usertype = value
    @property
    def template_data(self):
        return self._template_data

    @template_data.setter
    def template_data(self, value):
        self._template_data = value
    @property
    def template_type(self):
        return self._template_type

    @template_type.setter
    def template_type(self, value):
        self._template_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_memo:
            if hasattr(self.biz_memo, 'to_alipay_dict'):
                params['biz_memo'] = self.biz_memo.to_alipay_dict()
            else:
                params['biz_memo'] = self.biz_memo
        if self.client_msg_id:
            if hasattr(self.client_msg_id, 'to_alipay_dict'):
                params['client_msg_id'] = self.client_msg_id.to_alipay_dict()
            else:
                params['client_msg_id'] = self.client_msg_id
        if self.link:
            if hasattr(self.link, 'to_alipay_dict'):
                params['link'] = self.link.to_alipay_dict()
            else:
                params['link'] = self.link
        if self.receiver_id:
            if hasattr(self.receiver_id, 'to_alipay_dict'):
                params['receiver_id'] = self.receiver_id.to_alipay_dict()
            else:
                params['receiver_id'] = self.receiver_id
        if self.receiver_usertype:
            if hasattr(self.receiver_usertype, 'to_alipay_dict'):
                params['receiver_usertype'] = self.receiver_usertype.to_alipay_dict()
            else:
                params['receiver_usertype'] = self.receiver_usertype
        if self.template_data:
            if hasattr(self.template_data, 'to_alipay_dict'):
                params['template_data'] = self.template_data.to_alipay_dict()
            else:
                params['template_data'] = self.template_data
        if self.template_type:
            if hasattr(self.template_type, 'to_alipay_dict'):
                params['template_type'] = self.template_type.to_alipay_dict()
            else:
                params['template_type'] = self.template_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipaySocialBaseChatSendModel()
        if 'biz_memo' in d:
            o.biz_memo = d['biz_memo']
        if 'client_msg_id' in d:
            o.client_msg_id = d['client_msg_id']
        if 'link' in d:
            o.link = d['link']
        if 'receiver_id' in d:
            o.receiver_id = d['receiver_id']
        if 'receiver_usertype' in d:
            o.receiver_usertype = d['receiver_usertype']
        if 'template_data' in d:
            o.template_data = d['template_data']
        if 'template_type' in d:
            o.template_type = d['template_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AgWeatherDisasterInfo(object):

    def __init__(self):
        self._actual_date = None
        self._addition_info = None
        self._forecast_date = None
        self._high_temperature_index = None
        self._high_temperature_level = None
        self._low_temperature_index = None
        self._low_temperature_level = None
        self._rainstorm_index = None
        self._rainstorm_level = None

    @property
    def actual_date(self):
        return self._actual_date

    @actual_date.setter
    def actual_date(self, value):
        self._actual_date = value
    @property
    def addition_info(self):
        return self._addition_info

    @addition_info.setter
    def addition_info(self, value):
        self._addition_info = value
    @property
    def forecast_date(self):
        return self._forecast_date

    @forecast_date.setter
    def forecast_date(self, value):
        self._forecast_date = value
    @property
    def high_temperature_index(self):
        return self._high_temperature_index

    @high_temperature_index.setter
    def high_temperature_index(self, value):
        self._high_temperature_index = value
    @property
    def high_temperature_level(self):
        return self._high_temperature_level

    @high_temperature_level.setter
    def high_temperature_level(self, value):
        self._high_temperature_level = value
    @property
    def low_temperature_index(self):
        return self._low_temperature_index

    @low_temperature_index.setter
    def low_temperature_index(self, value):
        self._low_temperature_index = value
    @property
    def low_temperature_level(self):
        return self._low_temperature_level

    @low_temperature_level.setter
    def low_temperature_level(self, value):
        self._low_temperature_level = value
    @property
    def rainstorm_index(self):
        return self._rainstorm_index

    @rainstorm_index.setter
    def rainstorm_index(self, value):
        self._rainstorm_index = value
    @property
    def rainstorm_level(self):
        return self._rainstorm_level

    @rainstorm_level.setter
    def rainstorm_level(self, value):
        self._rainstorm_level = value


    def to_alipay_dict(self):
        params = dict()
        if self.actual_date:
            if hasattr(self.actual_date, 'to_alipay_dict'):
                params['actual_date'] = self.actual_date.to_alipay_dict()
            else:
                params['actual_date'] = self.actual_date
        if self.addition_info:
            if hasattr(self.addition_info, 'to_alipay_dict'):
                params['addition_info'] = self.addition_info.to_alipay_dict()
            else:
                params['addition_info'] = self.addition_info
        if self.forecast_date:
            if hasattr(self.forecast_date, 'to_alipay_dict'):
                params['forecast_date'] = self.forecast_date.to_alipay_dict()
            else:
                params['forecast_date'] = self.forecast_date
        if self.high_temperature_index:
            if hasattr(self.high_temperature_index, 'to_alipay_dict'):
                params['high_temperature_index'] = self.high_temperature_index.to_alipay_dict()
            else:
                params['high_temperature_index'] = self.high_temperature_index
        if self.high_temperature_level:
            if hasattr(self.high_temperature_level, 'to_alipay_dict'):
                params['high_temperature_level'] = self.high_temperature_level.to_alipay_dict()
            else:
                params['high_temperature_level'] = self.high_temperature_level
        if self.low_temperature_index:
            if hasattr(self.low_temperature_index, 'to_alipay_dict'):
                params['low_temperature_index'] = self.low_temperature_index.to_alipay_dict()
            else:
                params['low_temperature_index'] = self.low_temperature_index
        if self.low_temperature_level:
            if hasattr(self.low_temperature_level, 'to_alipay_dict'):
                params['low_temperature_level'] = self.low_temperature_level.to_alipay_dict()
            else:
                params['low_temperature_level'] = self.low_temperature_level
        if self.rainstorm_index:
            if hasattr(self.rainstorm_index, 'to_alipay_dict'):
                params['rainstorm_index'] = self.rainstorm_index.to_alipay_dict()
            else:
                params['rainstorm_index'] = self.rainstorm_index
        if self.rainstorm_level:
            if hasattr(self.rainstorm_level, 'to_alipay_dict'):
                params['rainstorm_level'] = self.rainstorm_level.to_alipay_dict()
            else:
                params['rainstorm_level'] = self.rainstorm_level
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AgWeatherDisasterInfo()
        if 'actual_date' in d:
            o.actual_date = d['actual_date']
        if 'addition_info' in d:
            o.addition_info = d['addition_info']
        if 'forecast_date' in d:
            o.forecast_date = d['forecast_date']
        if 'high_temperature_index' in d:
            o.high_temperature_index = d['high_temperature_index']
        if 'high_temperature_level' in d:
            o.high_temperature_level = d['high_temperature_level']
        if 'low_temperature_index' in d:
            o.low_temperature_index = d['low_temperature_index']
        if 'low_temperature_level' in d:
            o.low_temperature_level = d['low_temperature_level']
        if 'rainstorm_index' in d:
            o.rainstorm_index = d['rainstorm_index']
        if 'rainstorm_level' in d:
            o.rainstorm_level = d['rainstorm_level']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.RepairItem import RepairItem


class AlipayInsAutoAutoaftermarketInserviceorderNotifyModel(object):

    def __init__(self):
        self._ant_ser_apply_no = None
        self._event_time = None
        self._extra = None
        self._inst_ser_apply_no = None
        self._repair_item = None
        self._status = None

    @property
    def ant_ser_apply_no(self):
        return self._ant_ser_apply_no

    @ant_ser_apply_no.setter
    def ant_ser_apply_no(self, value):
        self._ant_ser_apply_no = value
    @property
    def event_time(self):
        return self._event_time

    @event_time.setter
    def event_time(self, value):
        self._event_time = value
    @property
    def extra(self):
        return self._extra

    @extra.setter
    def extra(self, value):
        self._extra = value
    @property
    def inst_ser_apply_no(self):
        return self._inst_ser_apply_no

    @inst_ser_apply_no.setter
    def inst_ser_apply_no(self, value):
        self._inst_ser_apply_no = value
    @property
    def repair_item(self):
        return self._repair_item

    @repair_item.setter
    def repair_item(self, value):
        if isinstance(value, list):
            self._repair_item = list()
            for i in value:
                if isinstance(i, RepairItem):
                    self._repair_item.append(i)
                else:
                    self._repair_item.append(RepairItem.from_alipay_dict(i))
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.ant_ser_apply_no:
            if hasattr(self.ant_ser_apply_no, 'to_alipay_dict'):
                params['ant_ser_apply_no'] = self.ant_ser_apply_no.to_alipay_dict()
            else:
                params['ant_ser_apply_no'] = self.ant_ser_apply_no
        if self.event_time:
            if hasattr(self.event_time, 'to_alipay_dict'):
                params['event_time'] = self.event_time.to_alipay_dict()
            else:
                params['event_time'] = self.event_time
        if self.extra:
            if hasattr(self.extra, 'to_alipay_dict'):
                params['extra'] = self.extra.to_alipay_dict()
            else:
                params['extra'] = self.extra
        if self.inst_ser_apply_no:
            if hasattr(self.inst_ser_apply_no, 'to_alipay_dict'):
                params['inst_ser_apply_no'] = self.inst_ser_apply_no.to_alipay_dict()
            else:
                params['inst_ser_apply_no'] = self.inst_ser_apply_no
        if self.repair_item:
            if isinstance(self.repair_item, list):
                for i in range(0, len(self.repair_item)):
                    element = self.repair_item[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.repair_item[i] = element.to_alipay_dict()
            if hasattr(self.repair_item, 'to_alipay_dict'):
                params['repair_item'] = self.repair_item.to_alipay_dict()
            else:
                params['repair_item'] = self.repair_item
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayInsAutoAutoaftermarketInserviceorderNotifyModel()
        if 'ant_ser_apply_no' in d:
            o.ant_ser_apply_no = d['ant_ser_apply_no']
        if 'event_time' in d:
            o.event_time = d['event_time']
        if 'extra' in d:
            o.extra = d['extra']
        if 'inst_ser_apply_no' in d:
            o.inst_ser_apply_no = d['inst_ser_apply_no']
        if 'repair_item' in d:
            o.repair_item = d['repair_item']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class TaskEventInfo(object):

    def __init__(self):
        self._task_event_id = None
        self._task_event_type = None

    @property
    def task_event_id(self):
        return self._task_event_id

    @task_event_id.setter
    def task_event_id(self, value):
        self._task_event_id = value
    @property
    def task_event_type(self):
        return self._task_event_type

    @task_event_type.setter
    def task_event_type(self, value):
        self._task_event_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.task_event_id:
            if hasattr(self.task_event_id, 'to_alipay_dict'):
                params['task_event_id'] = self.task_event_id.to_alipay_dict()
            else:
                params['task_event_id'] = self.task_event_id
        if self.task_event_type:
            if hasattr(self.task_event_type, 'to_alipay_dict'):
                params['task_event_type'] = self.task_event_type.to_alipay_dict()
            else:
                params['task_event_type'] = self.task_event_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TaskEventInfo()
        if 'task_event_id' in d:
            o.task_event_id = d['task_event_id']
        if 'task_event_type' in d:
            o.task_event_type = d['task_event_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.PageTemplateInfoDTO import PageTemplateInfoDTO


class DatadigitalFincloudFinsaasDesignPagetemplateQueryResponse(AlipayResponse):

    def __init__(self):
        super(DatadigitalFincloudFinsaasDesignPagetemplateQueryResponse, self).__init__()
        self._template_code = None
        self._template_info = None

    @property
    def template_code(self):
        return self._template_code

    @template_code.setter
    def template_code(self, value):
        self._template_code = value
    @property
    def template_info(self):
        return self._template_info

    @template_info.setter
    def template_info(self, value):
        if isinstance(value, PageTemplateInfoDTO):
            self._template_info = value
        else:
            self._template_info = PageTemplateInfoDTO.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(DatadigitalFincloudFinsaasDesignPagetemplateQueryResponse, self).parse_response_content(response_content)
        if 'template_code' in response:
            self.template_code = response['template_code']
        if 'template_info' in response:
            self.template_info = response['template_info']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayPlatformUseridGetResponse(AlipayResponse):

    def __init__(self):
        super(AlipayPlatformUseridGetResponse, self).__init__()
        self._dict = None

    @property
    def dict(self):
        return self._dict

    @dict.setter
    def dict(self, value):
        self._dict = value

    def parse_response_content(self, response_content):
        response = super(AlipayPlatformUseridGetResponse, self).parse_response_content(response_content)
        if 'dict' in response:
            self.dict = response['dict']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZhimaMerchantContractPageQueryModel(object):

    def __init__(self):
        self._begin_time = None
        self._contract_status_list = None
        self._current_page = None
        self._end_time = None
        self._include_event_detail = None
        self._include_item = None
        self._offer_no = None
        self._page_size = None
        self._sign_principal_id = None

    @property
    def begin_time(self):
        return self._begin_time

    @begin_time.setter
    def begin_time(self, value):
        self._begin_time = value
    @property
    def contract_status_list(self):
        return self._contract_status_list

    @contract_status_list.setter
    def contract_status_list(self, value):
        self._contract_status_list = value
    @property
    def current_page(self):
        return self._current_page

    @current_page.setter
    def current_page(self, value):
        self._current_page = value
    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def include_event_detail(self):
        return self._include_event_detail

    @include_event_detail.setter
    def include_event_detail(self, value):
        self._include_event_detail = value
    @property
    def include_item(self):
        return self._include_item

    @include_item.setter
    def include_item(self, value):
        self._include_item = value
    @property
    def offer_no(self):
        return self._offer_no

    @offer_no.setter
    def offer_no(self, value):
        self._offer_no = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def sign_principal_id(self):
        return self._sign_principal_id

    @sign_principal_id.setter
    def sign_principal_id(self, value):
        self._sign_principal_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.begin_time:
            if hasattr(self.begin_time, 'to_alipay_dict'):
                params['begin_time'] = self.begin_time.to_alipay_dict()
            else:
                params['begin_time'] = self.begin_time
        if self.contract_status_list:
            if hasattr(self.contract_status_list, 'to_alipay_dict'):
                params['contract_status_list'] = self.contract_status_list.to_alipay_dict()
            else:
                params['contract_status_list'] = self.contract_status_list
        if self.current_page:
            if hasattr(self.current_page, 'to_alipay_dict'):
                params['current_page'] = self.current_page.to_alipay_dict()
            else:
                params['current_page'] = self.current_page
        if self.end_time:
            if hasattr(self.end_time, 'to_alipay_dict'):
                params['end_time'] = self.end_time.to_alipay_dict()
            else:
                params['end_time'] = self.end_time
        if self.include_event_detail:
            if hasattr(self.include_event_detail, 'to_alipay_dict'):
                params['include_event_detail'] = self.include_event_detail.to_alipay_dict()
            else:
                params['include_event_detail'] = self.include_event_detail
        if self.include_item:
            if hasattr(self.include_item, 'to_alipay_dict'):
                params['include_item'] = self.include_item.to_alipay_dict()
            else:
                params['include_item'] = self.include_item
        if self.offer_no:
            if hasattr(self.offer_no, 'to_alipay_dict'):
                params['offer_no'] = self.offer_no.to_alipay_dict()
            else:
                params['offer_no'] = self.offer_no
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.sign_principal_id:
            if hasattr(self.sign_principal_id, 'to_alipay_dict'):
                params['sign_principal_id'] = self.sign_principal_id.to_alipay_dict()
            else:
                params['sign_principal_id'] = self.sign_principal_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaMerchantContractPageQueryModel()
        if 'begin_time' in d:
            o.begin_time = d['begin_time']
        if 'contract_status_list' in d:
            o.contract_status_list = d['contract_status_list']
        if 'current_page' in d:
            o.current_page = d['current_page']
        if 'end_time' in d:
            o.end_time = d['end_time']
        if 'include_event_detail' in d:
            o.include_event_detail = d['include_event_detail']
        if 'include_item' in d:
            o.include_item = d['include_item']
        if 'offer_no' in d:
            o.offer_no = d['offer_no']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'sign_principal_id' in d:
            o.sign_principal_id = d['sign_principal_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CodeResult(object):

    def __init__(self):
        self._code = None
        self._code_token = None
        self._code_url = None

    @property
    def code(self):
        return self._code

    @code.setter
    def code(self, value):
        self._code = value
    @property
    def code_token(self):
        return self._code_token

    @code_token.setter
    def code_token(self, value):
        self._code_token = value
    @property
    def code_url(self):
        return self._code_url

    @code_url.setter
    def code_url(self, value):
        self._code_url = value


    def to_alipay_dict(self):
        params = dict()
        if self.code:
            if hasattr(self.code, 'to_alipay_dict'):
                params['code'] = self.code.to_alipay_dict()
            else:
                params['code'] = self.code
        if self.code_token:
            if hasattr(self.code_token, 'to_alipay_dict'):
                params['code_token'] = self.code_token.to_alipay_dict()
            else:
                params['code_token'] = self.code_token
        if self.code_url:
            if hasattr(self.code_url, 'to_alipay_dict'):
                params['code_url'] = self.code_url.to_alipay_dict()
            else:
                params['code_url'] = self.code_url
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CodeResult()
        if 'code' in d:
            o.code = d['code']
        if 'code_token' in d:
            o.code_token = d['code_token']
        if 'code_url' in d:
            o.code_url = d['code_url']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MiniEntityBindInfo import MiniEntityBindInfo


class AlipayOpenMiniShopRelationBindModel(object):

    def __init__(self):
        self._entity_info = None
        self._operation = None

    @property
    def entity_info(self):
        return self._entity_info

    @entity_info.setter
    def entity_info(self, value):
        if isinstance(value, list):
            self._entity_info = list()
            for i in value:
                if isinstance(i, MiniEntityBindInfo):
                    self._entity_info.append(i)
                else:
                    self._entity_info.append(MiniEntityBindInfo.from_alipay_dict(i))
    @property
    def operation(self):
        return self._operation

    @operation.setter
    def operation(self, value):
        self._operation = value


    def to_alipay_dict(self):
        params = dict()
        if self.entity_info:
            if isinstance(self.entity_info, list):
                for i in range(0, len(self.entity_info)):
                    element = self.entity_info[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.entity_info[i] = element.to_alipay_dict()
            if hasattr(self.entity_info, 'to_alipay_dict'):
                params['entity_info'] = self.entity_info.to_alipay_dict()
            else:
                params['entity_info'] = self.entity_info
        if self.operation:
            if hasattr(self.operation, 'to_alipay_dict'):
                params['operation'] = self.operation.to_alipay_dict()
            else:
                params['operation'] = self.operation
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniShopRelationBindModel()
        if 'entity_info' in d:
            o.entity_info = d['entity_info']
        if 'operation' in d:
            o.operation = d['operation']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class KoubeiCateringPosSidedishbatchSaveResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiCateringPosSidedishbatchSaveResponse, self).__init__()
        self._ids = None

    @property
    def ids(self):
        return self._ids

    @ids.setter
    def ids(self, value):
        if isinstance(value, list):
            self._ids = list()
            for i in value:
                self._ids.append(i)

    def parse_response_content(self, response_content):
        response = super(KoubeiCateringPosSidedishbatchSaveResponse, self).parse_response_content(response_content)
        if 'ids' in response:
            self.ids = response['ids']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class EndTimeInfo(object):

    def __init__(self):
        self._end_time = None
        self._end_time_type = None

    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def end_time_type(self):
        return self._end_time_type

    @end_time_type.setter
    def end_time_type(self, value):
        self._end_time_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.end_time:
            if hasattr(self.end_time, 'to_alipay_dict'):
                params['end_time'] = self.end_time.to_alipay_dict()
            else:
                params['end_time'] = self.end_time
        if self.end_time_type:
            if hasattr(self.end_time_type, 'to_alipay_dict'):
                params['end_time_type'] = self.end_time_type.to_alipay_dict()
            else:
                params['end_time_type'] = self.end_time_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = EndTimeInfo()
        if 'end_time' in d:
            o.end_time = d['end_time']
        if 'end_time_type' in d:
            o.end_time_type = d['end_time_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.AntSignTaskResult import AntSignTaskResult


class AlipayBossProdAntsignDetailQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayBossProdAntsignDetailQueryResponse, self).__init__()
        self._ant_sign_task_result_list = None
        self._app_name = None
        self._biz_no = None
        self._sign_flow_id = None
        self._status = None
        self._tenant = None

    @property
    def ant_sign_task_result_list(self):
        return self._ant_sign_task_result_list

    @ant_sign_task_result_list.setter
    def ant_sign_task_result_list(self, value):
        if isinstance(value, list):
            self._ant_sign_task_result_list = list()
            for i in value:
                if isinstance(i, AntSignTaskResult):
                    self._ant_sign_task_result_list.append(i)
                else:
                    self._ant_sign_task_result_list.append(AntSignTaskResult.from_alipay_dict(i))
    @property
    def app_name(self):
        return self._app_name

    @app_name.setter
    def app_name(self, value):
        self._app_name = value
    @property
    def biz_no(self):
        return self._biz_no

    @biz_no.setter
    def biz_no(self, value):
        self._biz_no = value
    @property
    def sign_flow_id(self):
        return self._sign_flow_id

    @sign_flow_id.setter
    def sign_flow_id(self, value):
        self._sign_flow_id = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def tenant(self):
        return self._tenant

    @tenant.setter
    def tenant(self, value):
        self._tenant = value

    def parse_response_content(self, response_content):
        response = super(AlipayBossProdAntsignDetailQueryResponse, self).parse_response_content(response_content)
        if 'ant_sign_task_result_list' in response:
            self.ant_sign_task_result_list = response['ant_sign_task_result_list']
        if 'app_name' in response:
            self.app_name = response['app_name']
        if 'biz_no' in response:
            self.biz_no = response['biz_no']
        if 'sign_flow_id' in response:
            self.sign_flow_id = response['sign_flow_id']
        if 'status' in response:
            self.status = response['status']
        if 'tenant' in response:
            self.tenant = response['tenant']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayInsAutoUserPointQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayInsAutoUserPointQueryResponse, self).__init__()
        self._can_exchange = None
        self._can_exchange_amount = None
        self._can_save_amount = None
        self._can_use_amount = None
        self._recommend_exchange = None
        self._total_limit = None
        self._total_save_amount = None

    @property
    def can_exchange(self):
        return self._can_exchange

    @can_exchange.setter
    def can_exchange(self, value):
        self._can_exchange = value
    @property
    def can_exchange_amount(self):
        return self._can_exchange_amount

    @can_exchange_amount.setter
    def can_exchange_amount(self, value):
        self._can_exchange_amount = value
    @property
    def can_save_amount(self):
        return self._can_save_amount

    @can_save_amount.setter
    def can_save_amount(self, value):
        self._can_save_amount = value
    @property
    def can_use_amount(self):
        return self._can_use_amount

    @can_use_amount.setter
    def can_use_amount(self, value):
        self._can_use_amount = value
    @property
    def recommend_exchange(self):
        return self._recommend_exchange

    @recommend_exchange.setter
    def recommend_exchange(self, value):
        self._recommend_exchange = value
    @property
    def total_limit(self):
        return self._total_limit

    @total_limit.setter
    def total_limit(self, value):
        self._total_limit = value
    @property
    def total_save_amount(self):
        return self._total_save_amount

    @total_save_amount.setter
    def total_save_amount(self, value):
        self._total_save_amount = value

    def parse_response_content(self, response_content):
        response = super(AlipayInsAutoUserPointQueryResponse, self).parse_response_content(response_content)
        if 'can_exchange' in response:
            self.can_exchange = response['can_exchange']
        if 'can_exchange_amount' in response:
            self.can_exchange_amount = response['can_exchange_amount']
        if 'can_save_amount' in response:
            self.can_save_amount = response['can_save_amount']
        if 'can_use_amount' in response:
            self.can_use_amount = response['can_use_amount']
        if 'recommend_exchange' in response:
            self.recommend_exchange = response['recommend_exchange']
        if 'total_limit' in response:
            self.total_limit = response['total_limit']
        if 'total_save_amount' in response:
            self.total_save_amount = response['total_save_amount']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ApSettleOrderQueryOrder(object):

    def __init__(self):
        self._apply_id = None
        self._bill_no = None
        self._end_date = None
        self._inst_id = None
        self._ip_role_id = None
        self._start_date = None
        self._status = None

    @property
    def apply_id(self):
        return self._apply_id

    @apply_id.setter
    def apply_id(self, value):
        self._apply_id = value
    @property
    def bill_no(self):
        return self._bill_no

    @bill_no.setter
    def bill_no(self, value):
        self._bill_no = value
    @property
    def end_date(self):
        return self._end_date

    @end_date.setter
    def end_date(self, value):
        self._end_date = value
    @property
    def inst_id(self):
        return self._inst_id

    @inst_id.setter
    def inst_id(self, value):
        self._inst_id = value
    @property
    def ip_role_id(self):
        return self._ip_role_id

    @ip_role_id.setter
    def ip_role_id(self, value):
        self._ip_role_id = value
    @property
    def start_date(self):
        return self._start_date

    @start_date.setter
    def start_date(self, value):
        self._start_date = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.apply_id:
            if hasattr(self.apply_id, 'to_alipay_dict'):
                params['apply_id'] = self.apply_id.to_alipay_dict()
            else:
                params['apply_id'] = self.apply_id
        if self.bill_no:
            if hasattr(self.bill_no, 'to_alipay_dict'):
                params['bill_no'] = self.bill_no.to_alipay_dict()
            else:
                params['bill_no'] = self.bill_no
        if self.end_date:
            if hasattr(self.end_date, 'to_alipay_dict'):
                params['end_date'] = self.end_date.to_alipay_dict()
            else:
                params['end_date'] = self.end_date
        if self.inst_id:
            if hasattr(self.inst_id, 'to_alipay_dict'):
                params['inst_id'] = self.inst_id.to_alipay_dict()
            else:
                params['inst_id'] = self.inst_id
        if self.ip_role_id:
            if hasattr(self.ip_role_id, 'to_alipay_dict'):
                params['ip_role_id'] = self.ip_role_id.to_alipay_dict()
            else:
                params['ip_role_id'] = self.ip_role_id
        if self.start_date:
            if hasattr(self.start_date, 'to_alipay_dict'):
                params['start_date'] = self.start_date.to_alipay_dict()
            else:
                params['start_date'] = self.start_date
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ApSettleOrderQueryOrder()
        if 'apply_id' in d:
            o.apply_id = d['apply_id']
        if 'bill_no' in d:
            o.bill_no = d['bill_no']
        if 'end_date' in d:
            o.end_date = d['end_date']
        if 'inst_id' in d:
            o.inst_id = d['inst_id']
        if 'ip_role_id' in d:
            o.ip_role_id = d['ip_role_id']
        if 'start_date' in d:
            o.start_date = d['start_date']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class FrequencyRuleDetail(object):

    def __init__(self):
        self._frequency_duration = None
        self._frequency_type = None
        self._total_times = None
        self._used_times = None

    @property
    def frequency_duration(self):
        return self._frequency_duration

    @frequency_duration.setter
    def frequency_duration(self, value):
        self._frequency_duration = value
    @property
    def frequency_type(self):
        return self._frequency_type

    @frequency_type.setter
    def frequency_type(self, value):
        self._frequency_type = value
    @property
    def total_times(self):
        return self._total_times

    @total_times.setter
    def total_times(self, value):
        self._total_times = value
    @property
    def used_times(self):
        return self._used_times

    @used_times.setter
    def used_times(self, value):
        self._used_times = value


    def to_alipay_dict(self):
        params = dict()
        if self.frequency_duration:
            if hasattr(self.frequency_duration, 'to_alipay_dict'):
                params['frequency_duration'] = self.frequency_duration.to_alipay_dict()
            else:
                params['frequency_duration'] = self.frequency_duration
        if self.frequency_type:
            if hasattr(self.frequency_type, 'to_alipay_dict'):
                params['frequency_type'] = self.frequency_type.to_alipay_dict()
            else:
                params['frequency_type'] = self.frequency_type
        if self.total_times:
            if hasattr(self.total_times, 'to_alipay_dict'):
                params['total_times'] = self.total_times.to_alipay_dict()
            else:
                params['total_times'] = self.total_times
        if self.used_times:
            if hasattr(self.used_times, 'to_alipay_dict'):
                params['used_times'] = self.used_times.to_alipay_dict()
            else:
                params['used_times'] = self.used_times
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = FrequencyRuleDetail()
        if 'frequency_duration' in d:
            o.frequency_duration = d['frequency_duration']
        if 'frequency_type' in d:
            o.frequency_type = d['frequency_type']
        if 'total_times' in d:
            o.total_times = d['total_times']
        if 'used_times' in d:
            o.used_times = d['used_times']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class OrderVoucherShopFailInfo(object):

    def __init__(self):
        self._fail_message = None
        self._fail_reasons = None
        self._shop_id = None

    @property
    def fail_message(self):
        return self._fail_message

    @fail_message.setter
    def fail_message(self, value):
        self._fail_message = value
    @property
    def fail_reasons(self):
        return self._fail_reasons

    @fail_reasons.setter
    def fail_reasons(self, value):
        if isinstance(value, list):
            self._fail_reasons = list()
            for i in value:
                self._fail_reasons.append(i)
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.fail_message:
            if hasattr(self.fail_message, 'to_alipay_dict'):
                params['fail_message'] = self.fail_message.to_alipay_dict()
            else:
                params['fail_message'] = self.fail_message
        if self.fail_reasons:
            if isinstance(self.fail_reasons, list):
                for i in range(0, len(self.fail_reasons)):
                    element = self.fail_reasons[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.fail_reasons[i] = element.to_alipay_dict()
            if hasattr(self.fail_reasons, 'to_alipay_dict'):
                params['fail_reasons'] = self.fail_reasons.to_alipay_dict()
            else:
                params['fail_reasons'] = self.fail_reasons
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OrderVoucherShopFailInfo()
        if 'fail_message' in d:
            o.fail_message = d['fail_message']
        if 'fail_reasons' in d:
            o.fail_reasons = d['fail_reasons']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class OpenFormFieldDO(object):

    def __init__(self):
        self._optional = None
        self._required = None

    @property
    def optional(self):
        return self._optional

    @optional.setter
    def optional(self, value):
        self._optional = value
    @property
    def required(self):
        return self._required

    @required.setter
    def required(self, value):
        self._required = value


    def to_alipay_dict(self):
        params = dict()
        if self.optional:
            if hasattr(self.optional, 'to_alipay_dict'):
                params['optional'] = self.optional.to_alipay_dict()
            else:
                params['optional'] = self.optional
        if self.required:
            if hasattr(self.required, 'to_alipay_dict'):
                params['required'] = self.required.to_alipay_dict()
            else:
                params['required'] = self.required
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OpenFormFieldDO()
        if 'optional' in d:
            o.optional = d['optional']
        if 'required' in d:
            o.required = d['required']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayUserAccountOperatorLogonpasswordVerifyResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserAccountOperatorLogonpasswordVerifyResponse, self).__init__()
        self._fail_reason = None
        self._fail_times = None
        self._verify_success = None

    @property
    def fail_reason(self):
        return self._fail_reason

    @fail_reason.setter
    def fail_reason(self, value):
        self._fail_reason = value
    @property
    def fail_times(self):
        return self._fail_times

    @fail_times.setter
    def fail_times(self, value):
        self._fail_times = value
    @property
    def verify_success(self):
        return self._verify_success

    @verify_success.setter
    def verify_success(self, value):
        self._verify_success = value

    def parse_response_content(self, response_content):
        response = super(AlipayUserAccountOperatorLogonpasswordVerifyResponse, self).parse_response_content(response_content)
        if 'fail_reason' in response:
            self.fail_reason = response['fail_reason']
        if 'fail_times' in response:
            self.fail_times = response['fail_times']
        if 'verify_success' in response:
            self.verify_success = response['verify_success']
